package com.lqkj.business.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.lqkj.business.entity.CameraInfo;
import com.lqkj.business.service.CameraInfoService;
import com.lqkj.camera.cache.CameraCacheUtil;
import com.lqkj.camera.config.CameraConfig;
import com.lqkj.camera.model.CameraVo;
import com.lqkj.camera.thread.CameraThread;
import com.lqkj.camera.util.HIKCameraUtils;
import com.lqkj.camera.util.UniviewCameraUtils;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.constant.Constants;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.core.redis.RedisCache;
import com.lqkj.common.core.text.Convert;
import com.lqkj.common.enums.BusinessType;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.lqkj.system.service.SysConfigService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * 监控信息Controller
 *
 * @author lh
 * @date 2022-09-30
 */
@Api(tags = {"监控信息"})
@RestController
@RequestMapping("/business/cameraInfo")
public class CameraInfoController extends BaseController
{
    public static final String univiewAccessTokenKey = "univiewAccessToken";
    @Autowired
    private CameraConfig cameraConfig;
    @Autowired
    private CameraInfoService cameraInfoService;
    @Autowired
    private SysConfigService configService;
    @Autowired
    private RedisCache redisCache;
    /**
     * 获取监控信息详细信息
     */
    @ApiOperation("获取监控流媒体地址")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:getCameraUrl')")
    @GetMapping(value = "/getCameraUrl/{cameraId}")
    public ResultUtil getCameraUrl(@PathVariable("cameraId") String cameraId)
    {
        String cameraProxyUrl = configService.selectConfigByKey("camera.proxy.url");
        CameraInfo cameraInfo = cameraInfoService.selectCameraInfoByCameraId(cameraId);
        CameraVo cameraVo = new CameraVo();
        switch (cameraInfo.getCameraType()){
            case "0": //自建流媒体
                if (CameraCacheUtil.STREAMMAP.containsKey(cameraId)){
                    cameraVo = CameraCacheUtil.STREAMMAP.get(cameraId);
                    cameraVo.setCount(cameraVo.getCount() + 1);
                    CameraCacheUtil.STREAMMAP.put(cameraId, cameraVo);
                    return ResultUtil.success(cameraVo);
                }else{
                    return ResultUtil.success(openStream(cameraId));
                }
            case "1": //海康平台
                String hikHost = configService.selectConfigByKey("hik.camera.host");
                String appKey = configService.selectConfigByKey("hik.camera.appKey");
                String appSecret = configService.selectConfigByKey("hik.camera.appSecret");
                String httpProtocol = configService.selectConfigByKey("hik.camera.httpProtocol");
                String requestBody = configService.selectConfigByKey("hik.camera.requestBody");
                String cameraViewUrl = HIKCameraUtils.getDefaultInstance(hikHost, appKey,appSecret, httpProtocol)
                        .getCameraPreviewURL(requestBody.replace("#cameraIndexCode", cameraInfo.getCameraIndexCode()));
                if (StringUtils.isNotEmpty(cameraProxyUrl)){
                    cameraVo.setHttpFlv(cameraProxyUrl + "hik/" + cameraViewUrl.substring(cameraViewUrl.indexOf("openUrl")));
                }else{
                    cameraVo.setHttpFlv(cameraViewUrl);
                }
                return ResultUtil.success(cameraVo);
            case "2": //宇视平台
                String univiewHost = configService.selectConfigByKey("uniview.camera.host");
                String univiewUsername = configService.selectConfigByKey("uniview.camera.username");
                String univiewPassword = configService.selectConfigByKey("uniview.camera.password");
                String univiewTSAddress = configService.selectConfigByKey("uniview.camera.TSAddress");
                String univiewTSPort = configService.selectConfigByKey("uniview.camera.TSPort");
                String accessToken = Convert.toStr(redisCache.getCacheObject(univiewAccessTokenKey));
                if (StringUtils.isEmpty(accessToken)){
                    accessToken = UniviewCameraUtils.getDefaultInstance(univiewHost, univiewUsername, univiewPassword)
                            .login();
                    if (StringUtils.isEmpty(accessToken)){
                        return ResultUtil.error("宇视平台登录失败，请检查服务是否可用");
                    }else{
                        redisCache.setCacheObject(univiewAccessTokenKey, accessToken, 1, TimeUnit.DAYS);
                    }
                }
                String result = UniviewCameraUtils.getDefaultInstance(univiewHost, univiewUsername, univiewPassword)
                        .getCameraPreviewUrl(accessToken, univiewTSAddress, univiewTSPort, cameraInfo.getCameraIndexCode());
                if (StringUtils.isEmpty(result)){
                    return ResultUtil.error("获取视频流地址失败");
                }else{
                    JSONObject resultJson = JSONObject.parseObject(result);
                    if (resultJson.getInteger("ErrCode") != 0){
                        redisCache.deleteObject(univiewAccessTokenKey);
                        return ResultUtil.error("获取视频流地址失败");
                    }
                    JSONObject data = resultJson.getJSONArray("Result").getJSONObject(0);

                    if (StringUtils.isNotEmpty(cameraProxyUrl)){
                        cameraVo.setHttpFlv(cameraProxyUrl + "uniview/" + data.getString("StreamURL").substring(data.getString("StreamURL").indexOf("hls")));
                    }else{
                        cameraVo.setHttpFlv(data.getString("StreamURL"));
                    }
                    return ResultUtil.success(cameraVo);
                }
            case "3": //大华平台
                return ResultUtil.success("暂不支持大华平台");
            case "4": //萤石云平台
                return ResultUtil.success("暂不支持萤石云平台");
            default:
                return ResultUtil.error("获取视频流地址失败");
        }

    }

    private CameraVo openStream(String cameraId){
        CameraInfo cameraInfo = cameraInfoService.selectCameraInfoByCameraId(cameraId);
        String rtmp = "rtmp://" + cameraConfig.getPushHost() + ":" + cameraConfig.getPushPort() + "/hls/" + cameraInfo.getCameraId();
        String httpHls = cameraConfig.getHttpFlvHost() + "/hls/" + cameraInfo.getCameraId() + ".m3u8";
        CameraVo cameraVo = new CameraVo();
        cameraVo.setRtsp(cameraInfo.getUrl());
        cameraVo.setToken(cameraInfo.getCameraId());
        cameraVo.setCount(1);
        cameraVo.setOpenTime(new Date());
        cameraVo.setHttpFlv(httpHls);
        cameraVo.setRtmp(rtmp);
        CameraThread.MyRunnable job = new CameraThread.MyRunnable(cameraVo);
        CameraThread.MyRunnable.es.execute(job);
        CameraCacheUtil.STREAMTHREAD.put(cameraInfo.getCameraId(),job);
        return cameraVo;
    }


    /**
     * 查询监控信息列表
     */
    @ApiOperation("查询监控信息列表")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(CameraInfo cameraInfo)
    {
        startPage( cameraInfo);
        PageInfo<CameraInfo> pageInfo = new PageInfo<>(cameraInfoService.selectCameraInfoList(cameraInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出监控信息列表
     */
    @ApiOperation("导出监控信息列表")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:export')")
    @Log(title = "监控信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(CameraInfo cameraInfo)
    {
        List<CameraInfo> list = cameraInfoService.selectCameraInfoList(cameraInfo);
        ExcelUtil<CameraInfo> util = new ExcelUtil<CameraInfo>(CameraInfo.class);
        return util.exportExcel(list, "监控信息数据");
    }

    /**
     * 获取监控信息详细信息
     */
    @ApiOperation("获取监控信息详细信息")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:query')")
    @GetMapping(value = "/{cameraId}")
    public ResultUtil getInfo(@PathVariable("cameraId") String cameraId)
    {
        return ResultUtil.success(cameraInfoService.selectCameraInfoByCameraId(cameraId));
    }

    /**
     * 新增监控信息
     */
    @ApiOperation("新增监控信息")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:add')")
    @Log(title = "监控信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody CameraInfo cameraInfo)
    {
        cameraInfo.setCreateBy(getUsername());
        return resultByRows(cameraInfoService.insertCameraInfo(cameraInfo));
    }

    /**
     * 修改监控信息
     */
    @ApiOperation("修改监控信息")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:edit')")
    @Log(title = "监控信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody CameraInfo cameraInfo)
    {
        cameraInfo.setUpdateBy(getUsername());
        return resultByRows(cameraInfoService.updateCameraInfo(cameraInfo));
    }

    /**
     * 删除监控信息
     */
    @ApiOperation("删除监控信息")
    @PreAuthorize("@ss.hasPermi('business:cameraInfo:remove')")
    @Log(title = "监控信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{cameraIds}")
    public ResultUtil remove(@PathVariable String[] cameraIds)
    {
        return resultByRows(cameraInfoService.deleteCameraInfoByCameraIds(cameraIds));
    }
}