package com.lqkj.business.controller;

import java.util.List;

import com.lqkj.system.entity.SysDept;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.business.entity.CmsCategory;
import com.lqkj.business.service.CmsCategoryService;
import com.lqkj.common.utils.poi.ExcelUtil;

/**
 * 信息分类Controller
 *
 * @author lqkj
 * @date 2023-02-14
 */
@Api(tags = {"信息分类"})
@RestController
@RequestMapping("/business/cmsCategory")
public class CmsCategoryController extends BaseController
{
    @Autowired
    private CmsCategoryService cmsCategoryService;

    @ApiOperation("根据父分类编号查询")
    @GetMapping("/front/child/{categoryId}")
    public ResultUtil selectByParentId(@PathVariable("categoryId") Long categoryId){
        CmsCategory category = new CmsCategory();
        category.setParentId(categoryId);
        return ResultUtil.success(cmsCategoryService.selectCmsCategoryList(category));
    }
    @ApiOperation("查询一级分类列表")
    @GetMapping("/parentList")
    public ResultUtil selectParentList(){
        return ResultUtil.success(cmsCategoryService.selectParentCategoryList());
    }
    /**
     * 查询信息分类列表
     */
    @ApiOperation("查询信息分类列表")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:list')")
    @GetMapping("/list")
    public ResultUtil list(CmsCategory cmsCategory)
    {
        List<CmsCategory> list = cmsCategoryService.selectCmsCategoryList(cmsCategory);
        return ResultUtil.success(list);
    }

    /**
     * 导出信息分类列表
     */
    @ApiOperation("导出信息分类列表")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:export')")
    @Log(title = "信息分类", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(CmsCategory cmsCategory)
    {
        List<CmsCategory> list = cmsCategoryService.selectCmsCategoryList(cmsCategory);
        ExcelUtil<CmsCategory> util = new ExcelUtil<CmsCategory>(CmsCategory.class);
        return util.exportExcel(list, "信息分类数据");
    }

    /**
     * 获取信息分类详细信息
     */
    @ApiOperation("获取信息分类详细信息")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:query')")
    @GetMapping(value = "/{categoryId}")
    public ResultUtil getInfo(@PathVariable("categoryId") Long categoryId)
    {
        return ResultUtil.success(cmsCategoryService.selectCmsCategoryByCategoryId(categoryId));
    }


    /**
     * 新增信息分类
     */
    @ApiOperation("新增信息分类")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:add')")
    @Log(title = "信息分类", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody CmsCategory cmsCategory)
    {
        if (cmsCategory.getParentId() == null){
            cmsCategory.setParentId(0l);
        }
        cmsCategory.setCreateBy(getNickName());
        return resultByRows(cmsCategoryService.insertCmsCategory(cmsCategory));
    }

    /**
     * 修改信息分类
     */
    @ApiOperation("修改信息分类")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:edit')")
    @Log(title = "信息分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody CmsCategory cmsCategory)
    {
        if(cmsCategory.getCategoryId().equals(cmsCategory.getParentId())){
            return ResultUtil.error("修改分类'" + cmsCategory.getName() + "'失败，父分类不能是自己");
        }
        if (cmsCategory.getParentId() == null){
            cmsCategory.setParentId(0l);
        }
        cmsCategory.setUpdateBy(getNickName());
        return resultByRows(cmsCategoryService.updateCmsCategory(cmsCategory));
    }

    /**
     * 删除信息分类
     */
    @ApiOperation("删除信息分类")
    @PreAuthorize("@ss.hasPermi('business:cmsCategory:remove')")
    @Log(title = "信息分类", businessType = BusinessType.DELETE)
    @DeleteMapping("/{categoryId}")
    public ResultUtil remove(@PathVariable Long categoryId)
    {
        if (cmsCategoryService.hasChildByCategoryId(categoryId)){
            return ResultUtil.error("存在下级栏目，不允许删除");
        }
        return resultByRows(cmsCategoryService.deleteCmsCategoryByCategoryId(categoryId));
    }

    /**
     * 获取分类下拉树列表
     */
    @ApiOperation("获取分类下拉树列表")
    @GetMapping("/treeselect")
    public ResultUtil treeselect()
    {
        List<CmsCategory> cmsCategories = cmsCategoryService.selectCmsCategoryList(null);
        return ResultUtil.success(cmsCategoryService.buildCategoryTreeSelect(cmsCategories));
    }
}
