package com.lqkj.business.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.business.entity.DeviceCategory;
import com.lqkj.business.service.DeviceCategoryService;
import com.lqkj.common.utils.poi.ExcelUtil;

/**
 * 设备分类Controller
 *
 * @author lqkj
 * @date 2023-03-14
 */
@Api(tags = {"设备分类"})
@RestController
@RequestMapping("/business/deviceCategory")
public class DeviceCategoryController extends BaseController
{
    @Autowired
    private DeviceCategoryService deviceCategoryService;
    @ApiOperation("查询一级分类列表")
    @GetMapping("/parentList")
    public ResultUtil selectParentList(){
        return ResultUtil.success(deviceCategoryService.selectParentCategoryList());
    }
    /**
     * 查询设备分类列表
     */
    @ApiOperation("查询设备分类列表")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:list')")
    @GetMapping("/list")
    public ResultUtil list(DeviceCategory deviceCategory)
    {
        List<DeviceCategory> list = deviceCategoryService.selectDeviceCategoryList(deviceCategory);
        return ResultUtil.success(list);
    }

    /**
     * 导出设备分类列表
     */
    @ApiOperation("导出设备分类列表")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:export')")
    @Log(title = "设备分类", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(DeviceCategory deviceCategory)
    {
        List<DeviceCategory> list = deviceCategoryService.selectDeviceCategoryList(deviceCategory);
        ExcelUtil<DeviceCategory> util = new ExcelUtil<DeviceCategory>(DeviceCategory.class);
        return util.exportExcel(list, "设备分类数据");
    }

    /**
     * 获取设备分类详细信息
     */
    @ApiOperation("获取设备分类详细信息")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:query')")
    @GetMapping(value = "/{categoryId}")
    public ResultUtil getInfo(@PathVariable("categoryId") Integer categoryId)
    {
        return ResultUtil.success(deviceCategoryService.selectDeviceCategoryByCategoryId(categoryId));
    }

    /**
     * 新增设备分类
     */
    @ApiOperation("新增设备分类")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:add')")
    @Log(title = "设备分类", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody DeviceCategory deviceCategory)
    {
        deviceCategory.setCreateBy(getNickName());
        return resultByRows(deviceCategoryService.insertDeviceCategory(deviceCategory));
    }

    /**
     * 修改设备分类
     */
    @ApiOperation("修改设备分类")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:edit')")
    @Log(title = "设备分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody DeviceCategory deviceCategory)
    {
        deviceCategory.setUpdateBy(getNickName());
        return resultByRows(deviceCategoryService.updateDeviceCategory(deviceCategory));
    }

    /**
     * 删除设备分类
     */
    @ApiOperation("删除设备分类")
    @PreAuthorize("@ss.hasPermi('business:deviceCategory:remove')")
    @Log(title = "设备分类", businessType = BusinessType.DELETE)
    @DeleteMapping("/{categoryIds}")
    public ResultUtil remove(@PathVariable Integer[] categoryIds)
    {
        return resultByRows(deviceCategoryService.deleteDeviceCategoryByCategoryIds(categoryIds));
    }
}
