package com.lqkj.business.service;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.time.LocalDateTime;
import java.util.stream.Collectors;

import com.lqkj.common.core.model.TreeSelect;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.system.entity.SysDept;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.business.mapper.CmsCategoryMapper;
import com.lqkj.business.entity.CmsCategory;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 信息分类Service业务层处理
 *
 * @author lqkj
 * @date 2023-02-14
 */
@Service
public class CmsCategoryService
{
    @Autowired
    private CmsCategoryMapper cmsCategoryMapper;

    /**
     * 查询信息分类
     *
     * @param categoryId 信息分类主键
     * @return 信息分类
     */

    public CmsCategory selectCmsCategoryByCategoryId(Long categoryId)
    {
        return cmsCategoryMapper.selectCmsCategoryByCategoryId(categoryId);
    }

    /**
     * 查询信息分类列表
     *
     * @param cmsCategory 信息分类
     * @return 信息分类
     */
    public List<CmsCategory> selectCmsCategoryList(CmsCategory cmsCategory)
    {
        return cmsCategoryMapper.selectCmsCategoryList(cmsCategory);
    }

    /**
     * 新增信息分类
     *
     * @param cmsCategory 信息分类
     * @return 结果
     */

    public int insertCmsCategory(CmsCategory cmsCategory)
    {
        cmsCategory.setCreateTime(LocalDateTime.now());
        return cmsCategoryMapper.insertCmsCategory(cmsCategory);
    }

    /**
     * 修改信息分类
     *
     * @param cmsCategory 信息分类
     * @return 结果
     */

    public int updateCmsCategory(CmsCategory cmsCategory)
    {
        cmsCategory.setUpdateTime(LocalDateTime.now());
        return cmsCategoryMapper.updateCmsCategory(cmsCategory);
    }

    /**
     * 批量删除信息分类
     *
     * @param categoryIds 需要删除的信息分类主键
     * @return 结果
     */

    public int deleteCmsCategoryByCategoryIds(Long[] categoryIds)
    {
        return cmsCategoryMapper.deleteCmsCategoryByCategoryIds(categoryIds);
    }

    /**
     * 删除信息分类信息
     *
     * @param categoryId 信息分类主键
     * @return 结果
     */

    public int deleteCmsCategoryByCategoryId(Long categoryId)
    {
        return cmsCategoryMapper.deleteCmsCategoryByCategoryId(categoryId);
    }

    public boolean hasChildByCategoryId(Long categoryId) {
        int result = cmsCategoryMapper.hasChildByCategoryId(categoryId);
        return result > 0 ? true : false;
    }

    public boolean checkExistCmsNews(Long categoryId) {
        int result = cmsCategoryMapper.checkExistCmsNews(categoryId);
        return result > 0 ? true :false;
    }

    public List<CmsCategory> selectParentCategoryList(){
        return cmsCategoryMapper.selectParentCategoryList();
    }



    public List<TreeSelect> buildCategoryTreeSelect(List<CmsCategory> cmsCategories)
    {
        List<CmsCategory> categoryTrees = buildCategoryTree(cmsCategories);
        return categoryTrees.stream().map(TreeSelect::new).collect(Collectors.toList());
    }
    /**
     * 得到子节点列表
     */
    private List<CmsCategory> getChildList(List<CmsCategory> list, CmsCategory t)
    {
        List<CmsCategory> tlist = new ArrayList<CmsCategory>();
        Iterator<CmsCategory> it = list.iterator();
        while (it.hasNext())
        {
            CmsCategory n = (CmsCategory) it.next();
            if (StringUtils.isNotNull(n.getParentId()) && n.getParentId().longValue() == t.getCategoryId().longValue())
            {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<CmsCategory> list, CmsCategory t)
    {
        return getChildList(list, t).size() > 0 ? true : false;
    }

    /**
     * 递归列表
     */
    private void recursionFn(List<CmsCategory> list, CmsCategory t)
    {
        // 得到子节点列表
        List<CmsCategory> childList = getChildList(list, t);
        t.setChildren(childList);
        for (CmsCategory tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }
    public List<CmsCategory> buildCategoryTree(List<CmsCategory> cmsCategories)
    {
        List<CmsCategory> returnList = new ArrayList<CmsCategory>();
        List<Long> tempList = new ArrayList<Long>();
        for (CmsCategory cmsCategory : cmsCategories)
        {
            tempList.add(cmsCategory.getCategoryId());
        }
        for (Iterator<CmsCategory> iterator = cmsCategories.iterator(); iterator.hasNext();)
        {
            CmsCategory category = (CmsCategory) iterator.next();
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(category.getParentId()))
            {
                recursionFn(cmsCategories, category);
                returnList.add(category);
            }
        }
        if (returnList.isEmpty())
        {
            returnList = cmsCategories;
        }
        return returnList;
    }
}
