package com.lqkj.camera.util;

import com.alibaba.fastjson.JSONObject;
import com.lqkj.common.utils.Base64;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.common.utils.http.HttpUtils;
import okhttp3.*;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.http.entity.ContentType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.nio.charset.StandardCharsets;

/**
 * 宇视相机调用接口
 */
public class UniviewCameraUtils {
    private static Logger logger = LoggerFactory.getLogger("uniview camera api");
    private static String host;
    private static String username;
    private static String password;
    private static UniviewCameraUtils univiewCameraUtils;
    private UniviewCameraUtils(){}

    private UniviewCameraUtils(String host, String username, String password){
        this.host = host;
        this.username = username;
        this.password = password;
    }
    public static synchronized UniviewCameraUtils getDefaultInstance(String host, String username, String password){
        if (univiewCameraUtils == null){
            univiewCameraUtils = new UniviewCameraUtils(host, username, password);
        }
        return univiewCameraUtils;
    }
    /**
     * 登录
     * @return
     */
    public String login(){
        String accessCode = "";
        String accessToken = "";
        Request request = new Request.Builder()
                .url(host + "login")
                .addHeader("Content-Type", ContentType.APPLICATION_JSON.getMimeType())
                .build();
        OkHttpClient okHttpClient = new OkHttpClient();
        try (Response response = okHttpClient.newCall(request).execute()) {
            if (response.code() == 200) {
                String result = response.body().string();
                if (StringUtils.isNotEmpty(result)){
                    JSONObject resultJson = JSONObject.parseObject(result);
                    accessCode = resultJson.getString("AccessCode");
                }
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        if (StringUtils.isNotEmpty(accessCode)){
            String loginSignature = DigestUtils.md5Hex(Base64.encode(username.getBytes(StandardCharsets.UTF_8)) + accessCode + DigestUtils.md5Hex(password));
            String body = "{\"UserName\":\"" + username +"\", \"AccessCode\":\"" + accessCode +"\", \"LoginSignature\":\"" + loginSignature+ "\"}";
            Request loginRequest = new Request.Builder()
                    .url(host + "login")
                    .post(RequestBody.create(body, MediaType.parse(ContentType.APPLICATION_JSON.getMimeType())))
                    .addHeader("Content-Type", ContentType.APPLICATION_JSON.getMimeType())
                    .build();
            OkHttpClient client = new OkHttpClient();
            try (Response response = client.newCall(loginRequest).execute()) {
                if (response.code() == 200) {
                    accessToken = response.header("Authorization");
                }
            } catch (Exception e) {
                logger.error(e.getMessage());
            }
        }
        return accessToken;
    }

    /**
     * 获取视频流地址
     * @param accessToken
     * @param TSAddress
     * @param TSPort
     * @param CamCode
     * @return
     */
    public String getCameraPreviewUrl(String accessToken,
                                      String TSAddress,
                                      String TSPort,
                                      String CamCode){
        String condition = "{\"ProtocolType\":1,\"TSAddress\":\"" + TSAddress + "\",\"TSPort\":" + TSPort+"," +
                "\"CamCodes\":[\"" + CamCode +"\"],\"StreamType\":0}";
        Request request = new Request.Builder()
                .url(host + "video/live?condition=" + condition)
                .addHeader("Content-Type", ContentType.APPLICATION_JSON.getMimeType())
                .addHeader("Authorization", accessToken)
                .get()
                .build();
        OkHttpClient client = new OkHttpClient();
        try (Response response = client.newCall(request).execute()) {
            if (response.code() == 200) {
                return response.body().string();
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
        return null;
    }

    /**
     * 分页查询相机状态
     * @return
     */
    public String pageQueryCamerasWithStatus(){
//        String condition = "{\"ProtocolType\":1,\"TSAddress\":\"" + TSAddress + "\",\"TSPort\":" + TSPort+"," +
//                "\"CamCodes\":[\"" + CamCode +"\"],\"StreamType\":0}";
//        Request request = new Request.Builder()
//                .url(host + "query?condition=" + condition)
//                .addHeader("Content-Type", ContentType.APPLICATION_JSON.getMimeType())
//                .addHeader("Authorization", accessToken)
//                .get()
//                .build();
        return null;
    }

}
