package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.AreaInfo;
import com.lqkj.info.service.AreaInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 区域对象：area_infoController
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"区域对象：area_info"})
@RestController
@RequestMapping("/info/areaInfo")
public class AreaInfoController extends BaseController
{
    @Autowired
    private AreaInfoService areaInfoService;

    /**
     * 查询区域对象：area_info列表
     */
    @ApiOperation("查询区域对象：area_info列表")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(AreaInfo areaInfo)
    {
        startPage( areaInfo);
        PageInfo<AreaInfo> pageInfo = new PageInfo<>(areaInfoService.selectAreaInfoList(areaInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出区域对象：area_info列表
     */
    @ApiOperation("导出区域对象：area_info列表")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:export')")
    @Log(title = "区域对象：area_info", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(AreaInfo areaInfo)
    {
        List<AreaInfo> list = areaInfoService.selectAreaInfoList(areaInfo);
        ExcelUtil<AreaInfo> util = new ExcelUtil<AreaInfo>(AreaInfo.class);
        return util.exportExcel(list, "区域对象：area_info数据");
    }

    /**
     * 获取区域对象：area_info详细信息
     */
    @ApiOperation("获取区域对象：area_info详细信息")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:query')")
    @GetMapping(value = "/{areaId}")
    public ResultUtil getInfo(@PathVariable("areaId") Integer areaId)
    {
        return ResultUtil.success(areaInfoService.selectAreaInfoByAreaId(areaId));
    }

    /**
     * 新增区域对象：area_info
     */
    @ApiOperation("新增区域对象：area_info")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:add')")
    @Log(title = "区域对象：area_info", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody AreaInfo areaInfo)
    {
        return resultByRows(areaInfoService.insertAreaInfo(areaInfo));
    }

    /**
     * 修改区域对象：area_info
     */
    @ApiOperation("修改区域对象：area_info")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:edit')")
    @Log(title = "区域对象：area_info", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody AreaInfo areaInfo)
    {
        return resultByRows(areaInfoService.updateAreaInfo(areaInfo));
    }

    /**
     * 删除区域对象：area_info
     */
    @ApiOperation("删除区域对象：area_info")
    @PreAuthorize("@ss.hasPermi('info:areaInfo:remove')")
    @Log(title = "区域对象：area_info", businessType = BusinessType.DELETE)
	@DeleteMapping("/{areaIds}")
    public ResultUtil remove(@PathVariable Integer[] areaIds)
    {
        return resultByRows(areaInfoService.deleteAreaInfoByAreaIds(areaIds));
    }
}