package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.EquipmentInfo;
import com.lqkj.info.service.EquipmentInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 设备信息Controller
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Api(tags = {"设备信息"})
@RestController
@RequestMapping("/info/equipmentInfo")
public class EquipmentInfoController extends BaseController
{
    @Autowired
    private EquipmentInfoService equipmentInfoService;

    /**
     * 查询设备信息列表
     */
    @ApiOperation("查询设备信息列表")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(EquipmentInfo equipmentInfo)
    {
        startPage( equipmentInfo);
        PageInfo<EquipmentInfo> pageInfo = new PageInfo<>(equipmentInfoService.selectEquipmentInfoList(equipmentInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出设备信息列表
     */
    @ApiOperation("导出设备信息列表")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:export')")
    @Log(title = "设备信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(EquipmentInfo equipmentInfo)
    {
        List<EquipmentInfo> list = equipmentInfoService.selectEquipmentInfoList(equipmentInfo);
        ExcelUtil<EquipmentInfo> util = new ExcelUtil<EquipmentInfo>(EquipmentInfo.class);
        return util.exportExcel(list, "设备信息数据");
    }

    /**
     * 获取设备信息详细信息
     */
    @ApiOperation("获取设备信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:query')")
    @GetMapping(value = "/{equipmentId}")
    public ResultUtil getInfo(@PathVariable("equipmentId") Integer equipmentId)
    {
        return ResultUtil.success(equipmentInfoService.selectEquipmentInfoByEquipmentId(equipmentId));
    }

    /**
     * 新增设备信息
     */
    @ApiOperation("新增设备信息")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:add')")
    @Log(title = "设备信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody EquipmentInfo equipmentInfo)
    {
        return resultByRows(equipmentInfoService.insertEquipmentInfo(equipmentInfo));
    }

    /**
     * 修改设备信息
     */
    @ApiOperation("修改设备信息")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:edit')")
    @Log(title = "设备信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody EquipmentInfo equipmentInfo)
    {
        return resultByRows(equipmentInfoService.updateEquipmentInfo(equipmentInfo));
    }

    /**
     * 删除设备信息
     */
    @ApiOperation("删除设备信息")
    @PreAuthorize("@ss.hasPermi('info:equipmentInfo:remove')")
    @Log(title = "设备信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{equipmentIds}")
    public ResultUtil remove(@PathVariable Integer[] equipmentIds)
    {
        return resultByRows(equipmentInfoService.deleteEquipmentInfoByEquipmentIds(equipmentIds));
    }

    @ApiOperation("查询所有监控")
    @GetMapping("/getAllMonitors")
    public ResultUtil selectEquipmentInfoList()
    {
    	return ResultUtil.success(equipmentInfoService.getAllMonitors());
    }
}