package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.OrganizationInfo;
import com.lqkj.info.service.OrganizationInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 主体信息Controller
 * 
 * @author lqkj
 * @date 2024-11-13
 */
@Api(tags = {"主体信息"})
@RestController
@RequestMapping("/info/organizationInfo")
public class OrganizationInfoController extends BaseController
{
    @Autowired
    private OrganizationInfoService organizationInfoService;

    /**
     * 查询主体信息列表
     */
    @ApiOperation("查询主体信息列表")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(OrganizationInfo organizationInfo)
    {
        startPage( organizationInfo);
        PageInfo<OrganizationInfo> pageInfo = new PageInfo<>(organizationInfoService.selectOrganizationInfoList(organizationInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出主体信息列表
     */
    @ApiOperation("导出主体信息列表")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:export')")
    @Log(title = "主体信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(OrganizationInfo organizationInfo)
    {
        List<OrganizationInfo> list = organizationInfoService.selectOrganizationInfoList(organizationInfo);
        ExcelUtil<OrganizationInfo> util = new ExcelUtil<OrganizationInfo>(OrganizationInfo.class);
        return util.exportExcel(list, "主体信息数据");
    }

    /**
     * 获取主体信息详细信息
     */
    @ApiOperation("获取主体信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:query')")
    @GetMapping(value = "/{organizationId}")
    public ResultUtil getInfo(@PathVariable("organizationId") Integer organizationId)
    {
        return ResultUtil.success(organizationInfoService.selectOrganizationInfoByOrganizationId(organizationId));
    }

    /**
     * 新增主体信息
     */
    @ApiOperation("新增主体信息")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:add')")
    @Log(title = "主体信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody OrganizationInfo organizationInfo)
    {
        return resultByRows(organizationInfoService.insertOrganizationInfo(organizationInfo));
    }

    /**
     * 修改主体信息
     */
    @ApiOperation("修改主体信息")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:edit')")
    @Log(title = "主体信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody OrganizationInfo organizationInfo)
    {
        return resultByRows(organizationInfoService.updateOrganizationInfo(organizationInfo));
    }

    /**
     * 删除主体信息
     */
    @ApiOperation("删除主体信息")
    @PreAuthorize("@ss.hasPermi('info:organizationInfo:remove')")
    @Log(title = "主体信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{organizationIds}")
    public ResultUtil remove(@PathVariable Integer[] organizationIds)
    {
        return resultByRows(organizationInfoService.deleteOrganizationInfoByOrganizationIds(organizationIds));
    }
}