package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ParkInfo;
import com.lqkj.info.service.ParkInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 园区对象Controller
 * 
 * @author lqkj
 * @date 2024-12-16
 */
@Api(tags = {"园区对象"})
@RestController
@RequestMapping("/info/parkInfo")
public class ParkInfoController extends BaseController
{
    @Autowired
    private ParkInfoService parkInfoService;

    /**
     * 查询园区对象列表
     */
    @ApiOperation("查询园区对象列表")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(ParkInfo parkInfo)
    {
        startPage( parkInfo);
        PageInfo<ParkInfo> pageInfo = new PageInfo<>(parkInfoService.selectParkInfoList(parkInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出园区对象列表
     */
    @ApiOperation("导出园区对象列表")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:export')")
    @Log(title = "园区对象", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ParkInfo parkInfo)
    {
        List<ParkInfo> list = parkInfoService.selectParkInfoList(parkInfo);
        ExcelUtil<ParkInfo> util = new ExcelUtil<ParkInfo>(ParkInfo.class);
        return util.exportExcel(list, "园区对象数据");
    }

    /**
     * 获取园区对象详细信息
     */
    @ApiOperation("获取园区对象详细信息")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:query')")
    @GetMapping(value = "/{parkId}")
    public ResultUtil getInfo(@PathVariable("parkId") Integer parkId)
    {
        return ResultUtil.success(parkInfoService.selectParkInfoByParkId(parkId));
    }

    /**
     * 新增园区对象
     */
    @ApiOperation("新增园区对象")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:add')")
    @Log(title = "园区对象", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ParkInfo parkInfo)
    {
        return resultByRows(parkInfoService.insertParkInfo(parkInfo));
    }

    /**
     * 修改园区对象
     */
    @ApiOperation("修改园区对象")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:edit')")
    @Log(title = "园区对象", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ParkInfo parkInfo)
    {
        return resultByRows(parkInfoService.updateParkInfo(parkInfo));
    }

    /**
     * 删除园区对象
     */
    @ApiOperation("删除园区对象")
    @PreAuthorize("@ss.hasPermi('info:parkInfo:remove')")
    @Log(title = "园区对象", businessType = BusinessType.DELETE)
	@DeleteMapping("/{parkIds}")
    public ResultUtil remove(@PathVariable Integer[] parkIds)
    {
        return resultByRows(parkInfoService.deleteParkInfoByParkIds(parkIds));
    }
}