package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.RoomInfo;
import com.lqkj.info.service.RoomInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 房间信息Controller
 * 
 * @author lqkj
 * @date 2024-11-13
 */
@Api(tags = {"房间信息"})
@RestController
@RequestMapping("/info/roomInfo")
public class RoomInfoController extends BaseController
{
    @Autowired
    private RoomInfoService roomInfoService;

    /**
     * 查询房间信息列表
     */
    @ApiOperation("查询房间信息列表")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(RoomInfo roomInfo)
    {
        startPage( roomInfo);
        PageInfo<RoomInfo> pageInfo = new PageInfo<>(roomInfoService.selectRoomInfoList(roomInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出房间信息列表
     */
    @ApiOperation("导出房间信息列表")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:export')")
    @Log(title = "房间信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(RoomInfo roomInfo)
    {
        List<RoomInfo> list = roomInfoService.selectRoomInfoList(roomInfo);
        ExcelUtil<RoomInfo> util = new ExcelUtil<RoomInfo>(RoomInfo.class);
        return util.exportExcel(list, "房间信息数据");
    }

    /**
     * 获取房间信息详细信息
     */
    @ApiOperation("获取房间信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:query')")
    @GetMapping(value = "/{roomId}")
    public ResultUtil getInfo(@PathVariable("roomId") Integer roomId)
    {
        return ResultUtil.success(roomInfoService.selectRoomInfoByRoomId(roomId));
    }

    /**
     * 新增房间信息
     */
    @ApiOperation("新增房间信息")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:add')")
    @Log(title = "房间信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody RoomInfo roomInfo)
    {
        return resultByRows(roomInfoService.insertRoomInfo(roomInfo));
    }

    /**
     * 修改房间信息
     */
    @ApiOperation("修改房间信息")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:edit')")
    @Log(title = "房间信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody RoomInfo roomInfo)
    {
        return resultByRows(roomInfoService.updateRoomInfo(roomInfo));
    }

    /**
     * 删除房间信息
     */
    @ApiOperation("删除房间信息")
    @PreAuthorize("@ss.hasPermi('info:roomInfo:remove')")
    @Log(title = "房间信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{roomIds}")
    public ResultUtil remove(@PathVariable Integer[] roomIds)
    {
        return resultByRows(roomInfoService.deleteRoomInfoByRoomIds(roomIds));
    }
}