package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ShiftPersonnel;
import com.lqkj.info.service.ShiftPersonnelService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 轮班人员信息Controller
 * 
 * @author lqkj
 * @date 2024-12-23
 */
@Api(tags = {"轮班人员信息"})
@RestController
@RequestMapping("/info/shiftPersonnel")
public class ShiftPersonnelController extends BaseController
{
    @Autowired
    private ShiftPersonnelService shiftPersonnelService;

    /**
     * 查询轮班人员信息列表
     */
    @ApiOperation("查询轮班人员信息列表")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:list')")
    @GetMapping("/list")
    public ResultUtil list(ShiftPersonnel shiftPersonnel)
    {
        startPage( shiftPersonnel);
        PageInfo<ShiftPersonnel> pageInfo = new PageInfo<>(shiftPersonnelService.selectShiftPersonnelList(shiftPersonnel));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出轮班人员信息列表
     */
    @ApiOperation("导出轮班人员信息列表")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:export')")
    @Log(title = "轮班人员信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ShiftPersonnel shiftPersonnel)
    {
        List<ShiftPersonnel> list = shiftPersonnelService.selectShiftPersonnelList(shiftPersonnel);
        ExcelUtil<ShiftPersonnel> util = new ExcelUtil<ShiftPersonnel>(ShiftPersonnel.class);
        return util.exportExcel(list, "轮班人员信息数据");
    }

    /**
     * 获取轮班人员信息详细信息
     */
    @ApiOperation("获取轮班人员信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:query')")
    @GetMapping(value = "/{personnelId}")
    public ResultUtil getInfo(@PathVariable("personnelId") Integer personnelId)
    {
        return ResultUtil.success(shiftPersonnelService.selectShiftPersonnelByPersonnelId(personnelId));
    }

    /**
     * 新增轮班人员信息
     */
    @ApiOperation("新增轮班人员信息")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:add')")
    @Log(title = "轮班人员信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ShiftPersonnel shiftPersonnel)
    {
        return resultByRows(shiftPersonnelService.insertShiftPersonnel(shiftPersonnel));
    }

    /**
     * 修改轮班人员信息
     */
    @ApiOperation("修改轮班人员信息")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:edit')")
    @Log(title = "轮班人员信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ShiftPersonnel shiftPersonnel)
    {
        return resultByRows(shiftPersonnelService.updateShiftPersonnel(shiftPersonnel));
    }

    /**
     * 删除轮班人员信息
     */
    @ApiOperation("删除轮班人员信息")
    @PreAuthorize("@ss.hasPermi('info:shiftPersonnel:remove')")
    @Log(title = "轮班人员信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{personnelIds}")
    public ResultUtil remove(@PathVariable Integer[] personnelIds)
    {
        return resultByRows(shiftPersonnelService.deleteShiftPersonnelByPersonnelIds(personnelIds));
    }
}