package com.lqkj.info.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.lqkj.info.entity.EquipmentInfo;
import org.apache.ibatis.annotations.Select;

/**
 * 设备信息Mapper接口
 * 
 * @author lqkj
 * @date 2024-11-12
 */
@Mapper
public interface EquipmentInfoMapper 
{
    /**
     * 查询设备信息
     * 
     * @param equipmentId 设备信息主键
     * @return 设备信息
     */
    public EquipmentInfo selectEquipmentInfoByEquipmentId(Integer equipmentId);

    /**
     * 查询设备信息列表
     * 
     * @param equipmentInfo 设备信息
     * @return 设备信息集合
     */
    public List<EquipmentInfo> selectEquipmentInfoList(EquipmentInfo equipmentInfo);

    /**
     * 新增设备信息
     * 
     * @param equipmentInfo 设备信息
     * @return 结果
     */
    public int insertEquipmentInfo(EquipmentInfo equipmentInfo);

    /**
     * 修改设备信息
     * 
     * @param equipmentInfo 设备信息
     * @return 结果
     */
    public int updateEquipmentInfo(EquipmentInfo equipmentInfo);

    /**
     * 删除设备信息
     * 
     * @param equipmentId 设备信息主键
     * @return 结果
     */
    public int deleteEquipmentInfoByEquipmentId(Integer equipmentId);

    /**
     * 批量删除设备信息
     * 
     * @param equipmentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquipmentInfoByEquipmentIds(Integer[] equipmentIds);

    @Select("SELECT * FROM equipment_info ei " +
            "WHERE ei.type_id IN (SELECT et.type_id FROM equipment_type et WHERE et.parent_id = 1)")
    List<EquipmentInfo> getAllMonitors();
}