package com.lqkj.info.service;

import java.util.List;
import java.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.info.mapper.PolicyInfoMapper;
import com.lqkj.info.entity.PolicyInfo;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 政策信息Service业务层处理
 * 
 * @author lqkj
 * @date 2024-11-15
 */
@Service
public class PolicyInfoService
{
    @Autowired
    private PolicyInfoMapper policyInfoMapper;

    /**
     * 查询政策信息
     * 
     * @param policyId 政策信息主键
     * @return 政策信息
     */
    
    public PolicyInfo selectPolicyInfoByPolicyId(Integer policyId)
    {
        return policyInfoMapper.selectPolicyInfoByPolicyId(policyId);
    }

    /**
     * 查询政策信息列表
     * 
     * @param policyInfo 政策信息
     * @return 政策信息
     */
    public List<PolicyInfo> selectPolicyInfoList(PolicyInfo policyInfo)
    {
        return policyInfoMapper.selectPolicyInfoList(policyInfo);
    }

    /**
     * 新增政策信息
     * 
     * @param policyInfo 政策信息
     * @return 结果
     */
    
    public int insertPolicyInfo(PolicyInfo policyInfo)
    {
        policyInfo.setCreateTime(LocalDateTime.now());
        return policyInfoMapper.insertPolicyInfo(policyInfo);
    }

    /**
     * 修改政策信息
     * 
     * @param policyInfo 政策信息
     * @return 结果
     */
    
    public int updatePolicyInfo(PolicyInfo policyInfo)
    {
        return policyInfoMapper.updatePolicyInfo(policyInfo);
    }

    /**
     * 批量删除政策信息
     * 
     * @param policyIds 需要删除的政策信息主键
     * @return 结果
     */
    
    public int deletePolicyInfoByPolicyIds(Integer[] policyIds)
    {
        return policyInfoMapper.deletePolicyInfoByPolicyIds(policyIds);
    }

    /**
     * 删除政策信息信息
     * 
     * @param policyId 政策信息主键
     * @return 结果
     */
    
    public int deletePolicyInfoByPolicyId(Integer policyId)
    {
        return policyInfoMapper.deletePolicyInfoByPolicyId(policyId);
    }
}