package com.lqkj.system.controller;

import java.util.List;

import com.lqkj.ApiVersion;
import com.lqkj.common.constant.UserConstants;
import com.lqkj.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.system.entity.SysApiConfig;
import com.lqkj.system.service.SysApiConfigService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;
import org.springframework.web.util.HtmlUtils;

/**
 * 接口配置Controller
 * 
 * @author lqkj
 * @date 2023-02-06
 */
@Api(tags = {"接口配置"})
@RestController
@RequestMapping("/" + ApiVersion.V1 + "/system/apiConfig")
public class SysApiConfigController extends BaseController
{
    @Autowired
    private SysApiConfigService sysApiConfigService;

    /**
     * 查询接口配置列表
     */
    @ApiOperation("查询接口配置列表")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:list')")
    @GetMapping("/list")
    public ResultUtil list(SysApiConfig sysApiConfig)
    {
        startPage( sysApiConfig);
        PageInfo<SysApiConfig> pageInfo = new PageInfo<>(sysApiConfigService.selectSysApiConfigList(sysApiConfig));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出接口配置列表
     */
    @ApiOperation("导出接口配置列表")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:export')")
    @Log(title = "接口配置", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(SysApiConfig sysApiConfig)
    {
        List<SysApiConfig> list = sysApiConfigService.selectSysApiConfigList(sysApiConfig);
        ExcelUtil<SysApiConfig> util = new ExcelUtil<SysApiConfig>(SysApiConfig.class);
        return util.exportExcel(list, "接口配置数据");
    }

    /**
     * 获取接口配置详细信息
     */
    @ApiOperation("获取接口配置详细信息")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:query')")
    @GetMapping(value = "/{id}")
    public ResultUtil getInfo(@PathVariable("id") String id)
    {
        return ResultUtil.success(sysApiConfigService.selectSysApiConfigById(id));
    }

    /**
     * 新增接口配置
     */
    @ApiOperation("新增接口配置")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:add')")
    @Log(title = "接口配置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody SysApiConfig sysApiConfig)
    {
        if (UserConstants.NOT_UNIQUE.equals(sysApiConfigService.checkRoutePathUnique(sysApiConfig)))
        {
            return ResultUtil.error("新增接口'" + sysApiConfig.getRoutePath() + "'失败，接口路由已存在");
        }
        sysApiConfig.setCreateBy(getNickName());
        sysApiConfig.setSqlStr(htmlUnescape(sysApiConfig.getSqlStr()));
        sysApiConfig.setParamExample(htmlUnescape(sysApiConfig.getParamExample()));
        return resultByRows(sysApiConfigService.insertSysApiConfig(sysApiConfig));
    }

    /**
     * 修改接口配置
     */
    @ApiOperation("修改接口配置")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:edit')")
    @Log(title = "接口配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody SysApiConfig sysApiConfig)
    {
        if (UserConstants.NOT_UNIQUE.equals(sysApiConfigService.checkRoutePathUnique(sysApiConfig)))
        {
            return ResultUtil.error("修改接口'" + sysApiConfig.getRoutePath() + "'失败，接口路由已存在");
        }
        sysApiConfig.setUpdateBy(getNickName());
        sysApiConfig.setSqlStr(htmlUnescape(sysApiConfig.getSqlStr()));
        sysApiConfig.setParamExample(htmlUnescape(sysApiConfig.getParamExample()));
        return resultByRows(sysApiConfigService.updateSysApiConfig(sysApiConfig));
    }

    /**
     * 删除接口配置
     */
    @ApiOperation("删除接口配置")
    @PreAuthorize("@ss.hasPermi('system:apiConfig:remove')")
    @Log(title = "接口配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultUtil remove(@PathVariable String[] ids)
    {
        return resultByRows(sysApiConfigService.deleteSysApiConfigByIds(ids));
    }
}
