package com.lqkj.system.controller;

import com.github.pagehelper.PageInfo;
import com.lqkj.ApiVersion;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import com.lqkj.system.entity.SysNotice;
import com.lqkj.system.service.SysNoticeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;


/**
 * 公告 信息操作处理
 * 
 * @author ruoyi
 */
@Api(tags = {"通知公告"})
@RestController
@RequestMapping("/" + ApiVersion.V1 + "/system/notice")
public class SysNoticeController extends BaseController
{
    @Autowired
    private SysNoticeService noticeService;

    /**
     * 获取公开公示列表
     */
    @ApiOperation("公开公示列表")
    @PreAuthorize("@ss.hasPermi('business:notice:openList')")
    @GetMapping("/openList")
    public ResultUtil openList(SysNotice notice){
        notice.setNoticeType("1");
        notice.setStatus("0");
        startPage(notice);
        PageInfo<SysNotice> pageInfo = new PageInfo<>(noticeService.selectNoticeList(notice));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 查看公开公示详情
     */
    @ApiOperation("公开公示详情")
    @PreAuthorize("@ss.hasPermi('business:notice:openDetail')")
    @GetMapping(value = "/openDetail/{noticeId}")
    public ResultUtil openDetail(@PathVariable Long noticeId)
    {
        SysNotice notice = new SysNotice();
        notice.setNoticeId(noticeId);
        notice.setNoticeType("1");
        return ResultUtil.success(noticeService.selectNoticeByIdAndType(notice));
    }

    /**
     * 获取政务信息列表
     */
    @ApiOperation("政务信息列表")
    @PreAuthorize("@ss.hasPermi('business:notice:orgList')")
    @GetMapping("/orgList")
    public ResultUtil orgList(SysNotice notice){
        notice.setNoticeType("2");
        notice.setStatus("0");
        startPage(notice);
        PageInfo<SysNotice> pageInfo = new PageInfo<>(noticeService.selectNoticeList(notice));
        return ResultUtil.success(pageInfo);
    }
    /**
     * 查看政务信息详情
     */
    @ApiOperation("政务信息详情")
    @PreAuthorize("@ss.hasPermi('business:notice:orgDetail')")
    @GetMapping(value = "/orgDetail/{noticeId}")
    public ResultUtil orgDetail(@PathVariable Long noticeId)
    {
        SysNotice notice = new SysNotice();
        notice.setNoticeId(noticeId);
        notice.setNoticeType("2");
        return ResultUtil.success(noticeService.selectNoticeByIdAndType(notice));
    }


    /**
     * 获取通知公告列表
     */
    @ApiOperation("获取通知公告列表")
    @PreAuthorize("@ss.hasPermi('business:notice:list')")
    @GetMapping("/list")
    public ResultUtil list(SysNotice notice)
    {
        startPage(notice);
        PageInfo<SysNotice> pageInfo = new PageInfo<>(noticeService.selectNoticeList(notice));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 根据通知公告编号获取详细信息
     */
    @ApiOperation("获取通知公告详情")
    @PreAuthorize("@ss.hasPermi('business:notice:query')")
    @GetMapping(value = "/{noticeId}")
    public ResultUtil getInfo(@PathVariable Long noticeId)
    {
        return ResultUtil.success(noticeService.selectNoticeById(noticeId));
    }

    /**
     * 新增通知公告
     */
    @ApiOperation("新增通知公告")
    @PreAuthorize("@ss.hasPermi('business:notice:add')")
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@Validated @RequestBody SysNotice notice)
    {
        notice.setNoticeTitle(htmlUnescape(notice.getNoticeTitle()));
        notice.setNoticeContent(htmlUnescape(notice.getNoticeContent()));
        notice.setCreateBy(getNickName());
        return resultByRows(noticeService.insertNotice(notice));
    }

    /**
     * 修改通知公告
     */
    @ApiOperation("修改通知公告")
    @PreAuthorize("@ss.hasPermi('business:notice:edit')")
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@Validated @RequestBody SysNotice notice)
    {
        notice.setNoticeTitle(htmlUnescape(notice.getNoticeTitle()));
        notice.setNoticeContent(htmlUnescape(notice.getNoticeContent()));
        notice.setUpdateBy(getNickName());
        return resultByRows(noticeService.updateNotice(notice));
    }

    /**
     * 删除通知公告
     */
    @ApiOperation("删除通知公告")
    @PreAuthorize("@ss.hasPermi('business:notice:remove')")
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{noticeIds}")
    public ResultUtil remove(@PathVariable Long[] noticeIds)
    {
        return resultByRows(noticeService.deleteNoticeByIds(noticeIds));
    }
}
