package com.lqkj.system.mapper;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Mapper;
import com.lqkj.system.entity.SysApiConfig;
import org.apache.ibatis.annotations.Select;

/**
 * 接口配置Mapper接口
 * 
 * @author lqkj
 * @date 2023-02-06
 */
@Mapper
public interface SysApiConfigMapper 
{

    /**
     * 根据路由查询接口配置
     * @param routePath
     * @return
     */
    public SysApiConfig selectSysApiConfigByRoutePath(String routePath);
    /**
     * 查询接口配置
     * 
     * @param id 接口配置主键
     * @return 接口配置
     */
    public SysApiConfig selectSysApiConfigById(String id);

    /**
     * 查询接口配置列表
     * 
     * @param sysApiConfig 接口配置
     * @return 接口配置集合
     */
    public List<SysApiConfig> selectSysApiConfigList(SysApiConfig sysApiConfig);

    /**
     * 新增接口配置
     * 
     * @param sysApiConfig 接口配置
     * @return 结果
     */
    public int insertSysApiConfig(SysApiConfig sysApiConfig);

    /**
     * 修改接口配置
     * 
     * @param sysApiConfig 接口配置
     * @return 结果
     */
    public int updateSysApiConfig(SysApiConfig sysApiConfig);

    /**
     * 删除接口配置
     * 
     * @param id 接口配置主键
     * @return 结果
     */
    public int deleteSysApiConfigById(String id);

    /**
     * 批量删除接口配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysApiConfigByIds(String[] ids);

    /**
     * 校验路由唯一性
     * @param sysApiConfig
     * @return
     */
    public int checkRoutePathUnique(SysApiConfig sysApiConfig);


    /**
     * 查询单个对象
     * @param sqlStr
     * @return
     */
    @Select("${sql}")
    public Map<String, Object> findMapData(String sqlStr);

    /**
     * 查询集合对象
     * @param sqlStr
     * @return
     */
    @Select("${sql}")
    public List<Map<String, Object>> findListData(String sqlStr);
}
