package com.lqkj.system.websocket;


import com.fasterxml.jackson.databind.ObjectMapper;
import com.lqkj.ApiVersion;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.utils.spring.SpringUtils;
import com.lqkj.framework.service.WsPermissionService;
import com.lqkj.system.domain.Server;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.websocket.*;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 服务器监控websocket方式
 */
@Component
@ServerEndpoint("/ws/" + ApiVersion.V1 + "/monitor/server")
public class ServerWebSocket {
    private Logger logger = LoggerFactory.getLogger(getClass());
    private static Map<String, Session> clients = new ConcurrentHashMap<>();
    private static ObjectMapper objectMapper = SpringUtils.getBean(ObjectMapper.class);
    private static WsPermissionService wsp = SpringUtils.getBean(WsPermissionService.class);

    @OnOpen
    public void onOpen(Session session) throws IOException {
        if (!wsp.hasPermissions(session, "monitor:server:list")){
            logger.debug("没有权限，请联系管理员授权");
            session.getAsyncRemote().sendText(objectMapper.writeValueAsString(ResultUtil.error("没有权限，请联系管理员授权")));
            session.close();
        }else{
            clients.put(session.getId(), session);
        }

    }
    /**
     * 连接关闭调用的方法
     */
    @OnClose
    public void onClose(Session session) {
        clients.remove(session.getId());
    }

    /**
     * 收到客户端消息后调用的方法
     * @param message
     * 客户端发送过来的消息
     */
    @OnMessage
    public void onMessage(String message, Session session) {
        logger.debug("服务端收到客户端[{}]的消息:{}", session.getId(), message);
    }

    @OnError
    public void onError(Session session, Throwable error) {
        logger.error("发生错误:{}",error.getMessage());
    }
    /**
     * 群发服务器信息
     */
    public void sendMessage() {
        try {
            Server server = new Server();
            server.copyTo();
            for (Map.Entry<String, Session> session : clients.entrySet()){
                session.getValue().getAsyncRemote().sendText(objectMapper.writeValueAsString(server));
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
        }
    }
}

