package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.PlanType;
import com.lqkj.type.service.PlanTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 规划类型Controller
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"规划类型"})
@RestController
@RequestMapping("/type/planType")
public class PlanTypeController extends BaseController
{
    @Autowired
    private PlanTypeService planTypeService;

    /**
     * 查询规划类型列表
     */
    @ApiOperation("查询规划类型列表")
    @PreAuthorize("@ss.hasPermi('type:planType:list')")
    @GetMapping("/list")
    public ResultUtil list(PlanType planType)
    {
        startPage( planType);
        PageInfo<PlanType> pageInfo = new PageInfo<>(planTypeService.selectPlanTypeList(planType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出规划类型列表
     */
    @ApiOperation("导出规划类型列表")
    @PreAuthorize("@ss.hasPermi('type:planType:export')")
    @Log(title = "规划类型", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(PlanType planType)
    {
        List<PlanType> list = planTypeService.selectPlanTypeList(planType);
        ExcelUtil<PlanType> util = new ExcelUtil<PlanType>(PlanType.class);
        return util.exportExcel(list, "规划类型数据");
    }

    /**
     * 获取规划类型详细信息
     */
    @ApiOperation("获取规划类型详细信息")
    @PreAuthorize("@ss.hasPermi('type:planType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(planTypeService.selectPlanTypeByTypeId(typeId));
    }

    /**
     * 新增规划类型
     */
    @ApiOperation("新增规划类型")
    @PreAuthorize("@ss.hasPermi('type:planType:add')")
    @Log(title = "规划类型", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody PlanType planType)
    {
        return resultByRows(planTypeService.insertPlanType(planType));
    }

    /**
     * 修改规划类型
     */
    @ApiOperation("修改规划类型")
    @PreAuthorize("@ss.hasPermi('type:planType:edit')")
    @Log(title = "规划类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody PlanType planType)
    {
        return resultByRows(planTypeService.updatePlanType(planType));
    }

    /**
     * 删除规划类型
     */
    @ApiOperation("删除规划类型")
    @PreAuthorize("@ss.hasPermi('type:planType:remove')")
    @Log(title = "规划类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(planTypeService.deletePlanTypeByTypeIds(typeIds));
    }
}