DROP TABLE IF EXISTS QRTZ_FIRED_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_PAUSED_TRIGGER_GRPS;
DROP TABLE IF EXISTS QRTZ_SCHEDULER_STATE;
DROP TABLE IF EXISTS QRTZ_LOCKS;
DROP TABLE IF EXISTS QRTZ_SIMPLE_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_SIMPROP_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_CRON_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_BLOB_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_TRIGGERS;
DROP TABLE IF EXISTS QRTZ_JOB_DETAILS;
DROP TABLE IF EXISTS QRTZ_CALENDARS;

-- ----------------------------
-- 1、存储每一个已配置的 jobDetail 的详细信息
-- ----------------------------
create table QRTZ_JOB_DETAILS (
      sched_name           varchar(120)    not null,
      job_name             varchar(200)    not null,
      job_group            varchar(200)    not null,
      description          varchar(250)    null,
      job_class_name       varchar(250)    not null,
      is_durable           bool      not null,
      is_nonconcurrent     bool      not null,
      is_update_data       bool      not null,
      requests_recovery    bool      not null,
      job_data             bytea            null,
      primary key (sched_name, job_name, job_group)
);
COMMENT ON COLUMN QRTZ_JOB_DETAILS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.job_name IS '任务名称';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.job_group IS '任务组名';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.description IS '相关介绍';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.job_class_name IS '执行任务类名称';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.is_durable IS '是否持久化';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.is_nonconcurrent IS '是否并发';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.is_update_data IS '是否更新数据';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.requests_recovery IS '是否接受恢复执行';
COMMENT ON COLUMN QRTZ_JOB_DETAILS.job_data IS '存放持久化job对象';
COMMENT ON TABLE QRTZ_JOB_DETAILS IS '任务详细信息表';
-- ----------------------------
-- 2、 存储已配置的 Trigger 的信息
-- ----------------------------
create table QRTZ_TRIGGERS (
       sched_name           varchar(120)    not null,
       trigger_name         varchar(200)    not null,
       trigger_group        varchar(200)    not null,
       job_name             varchar(200)    not null,
       job_group            varchar(200)    not null,
       description          varchar(250)    null,
       next_fire_time       int8      null,
       prev_fire_time       int8      null,
       priority             int4         null,
       trigger_state        varchar(16)     not null,
       trigger_type         varchar(8)      not null,
       start_time           int8      not null,
       end_time             int8      null,
       calendar_name        varchar(200)    null,
       misfire_instr        int2     null,
       job_data             bytea            null,
       primary key (sched_name, trigger_name, trigger_group),
       foreign key (sched_name, job_name, job_group) references QRTZ_JOB_DETAILS(sched_name, job_name, job_group)
);
COMMENT ON COLUMN QRTZ_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_TRIGGERS.trigger_name IS '触发器的名字';
COMMENT ON COLUMN QRTZ_TRIGGERS.trigger_group IS '触发器所属组的名字';
COMMENT ON COLUMN QRTZ_TRIGGERS.job_name IS 'qrtz_job_details表job_name的外键';
COMMENT ON COLUMN QRTZ_TRIGGERS.job_group IS 'qrtz_job_details表job_group的外键';
COMMENT ON COLUMN QRTZ_TRIGGERS.description IS '相关介绍';
COMMENT ON COLUMN QRTZ_TRIGGERS.next_fire_time IS '上一次触发时间（毫秒）';
COMMENT ON COLUMN QRTZ_TRIGGERS.prev_fire_time IS '下一次触发时间（默认为-1表示不触发）';
COMMENT ON COLUMN QRTZ_TRIGGERS.priority IS '优先级';
COMMENT ON COLUMN QRTZ_TRIGGERS.trigger_state IS '触发器状态';
COMMENT ON COLUMN QRTZ_TRIGGERS.trigger_type IS '触发器的类型';
COMMENT ON COLUMN QRTZ_TRIGGERS.start_time IS '开始时间';
COMMENT ON COLUMN QRTZ_TRIGGERS.end_time IS '结束时间';
COMMENT ON COLUMN QRTZ_TRIGGERS.calendar_name IS '日程表名称';
COMMENT ON COLUMN QRTZ_TRIGGERS.misfire_instr IS '补偿执行的策略';
COMMENT ON COLUMN QRTZ_TRIGGERS.job_data IS '存放持久化job对象';
COMMENT ON TABLE QRTZ_TRIGGERS IS '触发器详细信息表';
-- ----------------------------
-- 3、 存储简单的 Trigger，包括重复次数，间隔，以及已触发的次数
-- ----------------------------
create table QRTZ_SIMPLE_TRIGGERS (
      sched_name           varchar(120)    not null,
      trigger_name         varchar(200)    not null,
      trigger_group        varchar(200)    not null,
      repeat_count         int8       not null,
      repeat_interval      int8      not null,
      times_triggered      int8      not null,
      primary key (sched_name, trigger_name, trigger_group),
      foreign key (sched_name, trigger_name, trigger_group) references QRTZ_TRIGGERS(sched_name, trigger_name, trigger_group)
);
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.trigger_name IS 'qrtz_triggers表trigger_name的外键';
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.repeat_count IS '重复的次数统计';
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.repeat_interval IS '重复的间隔时间';
COMMENT ON COLUMN QRTZ_SIMPLE_TRIGGERS.times_triggered IS '已经触发的次数';
COMMENT ON TABLE QRTZ_SIMPLE_TRIGGERS IS '简单触发器的信息表';
-- ----------------------------
-- 4、 存储 Cron Trigger，包括 Cron 表达式和时区信息
-- ----------------------------
create table QRTZ_CRON_TRIGGERS (
        sched_name           varchar(120)    not null,
        trigger_name         varchar(200)    not null,
        trigger_group        varchar(200)    not null,
        cron_expression      varchar(200)    not null,
        time_zone_id         varchar(80)     null,
        primary key (sched_name, trigger_name, trigger_group),
        foreign key (sched_name, trigger_name, trigger_group) references QRTZ_TRIGGERS(sched_name, trigger_name, trigger_group)
);
COMMENT ON COLUMN QRTZ_CRON_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_CRON_TRIGGERS.trigger_name IS 'qrtz_triggers表trigger_name的外键';
COMMENT ON COLUMN QRTZ_CRON_TRIGGERS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON COLUMN QRTZ_CRON_TRIGGERS.cron_expression IS 'cron表达式';
COMMENT ON COLUMN QRTZ_CRON_TRIGGERS.time_zone_id IS '时区';
COMMENT ON TABLE QRTZ_CRON_TRIGGERS IS 'Cron类型的触发器表';
-- ----------------------------
-- 5、 Trigger 作为 Blob 类型存储(用于 Quartz 用户用 JDBC 创建他们自己定制的 Trigger 类型，JobStore 并不知道如何存储实例的时候)
-- ----------------------------
create table QRTZ_BLOB_TRIGGERS (
        sched_name           varchar(120)    not null,
        trigger_name         varchar(200)    not null,
        trigger_group        varchar(200)    not null,
        blob_data            bytea            null ,
        primary key (sched_name, trigger_name, trigger_group),
        foreign key (sched_name, trigger_name, trigger_group) references QRTZ_TRIGGERS(sched_name, trigger_name, trigger_group)
);
COMMENT ON COLUMN QRTZ_BLOB_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_BLOB_TRIGGERS.trigger_name IS 'qrtz_triggers表trigger_name的外键';
COMMENT ON COLUMN QRTZ_BLOB_TRIGGERS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON COLUMN QRTZ_BLOB_TRIGGERS.blob_data IS '存放持久化Trigger对象';
COMMENT ON TABLE QRTZ_BLOB_TRIGGERS IS 'Blob类型的触发器表';
-- ----------------------------
-- 6、 以 Blob 类型存储存放日历信息， quartz可配置一个日历来指定一个时间范围
-- ----------------------------
create table QRTZ_CALENDARS (
        sched_name           varchar(120)    not null,
        calendar_name        varchar(200)    not null,
        calendar             bytea            not null,
        primary key (sched_name, calendar_name)
);
COMMENT ON COLUMN QRTZ_CALENDARS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_CALENDARS.calendar_name IS '日历名称';
COMMENT ON COLUMN QRTZ_CALENDARS.calendar IS '存放持久化calendar对象';
COMMENT ON TABLE QRTZ_CALENDARS IS '日历信息表';
-- ----------------------------
-- 7、 存储已暂停的 Trigger 组的信息
-- ----------------------------
create table QRTZ_PAUSED_TRIGGER_GRPS (
      sched_name           varchar(120)    not null,
      trigger_group        varchar(200)    not null,
      primary key (sched_name, trigger_group)
);
COMMENT ON COLUMN QRTZ_PAUSED_TRIGGER_GRPS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_PAUSED_TRIGGER_GRPS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON TABLE QRTZ_PAUSED_TRIGGER_GRPS IS '暂停的触发器表';
-- ----------------------------
-- 8、 存储与已触发的 Trigger 相关的状态信息，以及相联 Job 的执行信息
-- ----------------------------
create table QRTZ_FIRED_TRIGGERS (
     sched_name           varchar(120)    not null,
     entry_id             varchar(95)     not null,
     trigger_name         varchar(200)    not null,
     trigger_group        varchar(200)    not null ,
     instance_name        varchar(200)    not null,
     fired_time           int8      not null,
     sched_time           int8      not null,
     priority             int4         not null,
     state                varchar(16)     not null ,
     job_name             varchar(200)    null,
     job_group            varchar(200)    null,
     is_nonconcurrent     bool      null,
     requests_recovery    bool      null,
     primary key (sched_name, entry_id)
);
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.entry_id IS '调度器实例id';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.trigger_name IS 'qrtz_triggers表trigger_name的外键';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.instance_name IS '调度器实例名';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.fired_time IS '触发的时间';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.sched_time IS '定时器制定的时间';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.priority IS '优先级';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.state IS '状态';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.job_name IS '任务名称';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.job_group IS '任务组名';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.is_nonconcurrent IS '是否并发';
COMMENT ON COLUMN QRTZ_FIRED_TRIGGERS.requests_recovery IS '是否接受恢复执行';
COMMENT ON TABLE QRTZ_FIRED_TRIGGERS IS '已触发的触发器表';
-- ----------------------------
-- 9、 存储少量的有关 Scheduler 的状态信息，假如是用于集群中，可以看到其他的 Scheduler 实例
-- ----------------------------
create table QRTZ_SCHEDULER_STATE (
      sched_name           varchar(120)    not null,
      instance_name        varchar(200)    not null,
      last_checkin_time    int8      not null,
      checkin_interval     int8      not null,
      primary key (sched_name, instance_name)
);
COMMENT ON COLUMN QRTZ_SCHEDULER_STATE.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_SCHEDULER_STATE.instance_name IS '实例名称';
COMMENT ON COLUMN QRTZ_SCHEDULER_STATE.last_checkin_time IS '上次检查时间';
COMMENT ON COLUMN QRTZ_SCHEDULER_STATE.checkin_interval IS '检查间隔时间';
COMMENT ON TABLE QRTZ_SCHEDULER_STATE IS '调度器状态表';
-- ----------------------------
-- 10、 存储程序的悲观锁的信息(假如使用了悲观锁)
-- ----------------------------
create table QRTZ_LOCKS (
    sched_name           varchar(120)    not null,
    lock_name            varchar(40)     not null,
    primary key (sched_name, lock_name)
);
COMMENT ON COLUMN QRTZ_LOCKS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_LOCKS.lock_name IS '悲观锁名称';
COMMENT ON TABLE QRTZ_LOCKS IS '存储的悲观锁信息表';
-- ----------------------------
-- 11、 Quartz集群实现同步机制的行锁表
-- ----------------------------
create table QRTZ_SIMPROP_TRIGGERS (
   sched_name           varchar(120)    not null,
   trigger_name         varchar(200)    not null,
   trigger_group        varchar(200)    not null,
   str_prop_1           varchar(512)    null,
   str_prop_2           varchar(512)    null,
   str_prop_3           varchar(512)    null,
   int_prop_1           int4          null,
   int_prop_2           int4          null,
   long_prop_1          int8          null,
   long_prop_2          int8          null,
   dec_prop_1           numeric(13,4)   null,
   dec_prop_2           numeric(13,4)   null,
   bool_prop_1          bool     null,
   bool_prop_2          bool      null,
   primary key (sched_name, trigger_name, trigger_group),
   foreign key (sched_name, trigger_name, trigger_group) references QRTZ_TRIGGERS(sched_name, trigger_name, trigger_group)
);
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.sched_name IS '调度名称';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.trigger_name IS 'qrtz_triggers表trigger_name的外键';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.trigger_group IS 'qrtz_triggers表trigger_group的外键';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.str_prop_1 IS 'String类型的trigger的第一个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.str_prop_2 IS 'String类型的trigger的第二个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.str_prop_3 IS 'String类型的trigger的第三个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.int_prop_1 IS 'int类型的trigger的第一个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.int_prop_2 IS 'int类型的trigger的第二个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.long_prop_1 IS 'long类型的trigger的第一个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.long_prop_2 IS 'long类型的trigger的第二个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.dec_prop_1 IS 'decimal类型的trigger的第一个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.dec_prop_2 IS 'decimal类型的trigger的第二个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.bool_prop_1 IS 'Boolean类型的trigger的第一个参数';
COMMENT ON COLUMN QRTZ_SIMPROP_TRIGGERS.bool_prop_2 IS 'Boolean类型的trigger的第二个参数';
COMMENT ON TABLE QRTZ_SIMPROP_TRIGGERS IS '同步机制的行锁表';



-- ----------------------------
-- 部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept (
      dept_id              SERIAL               not null,
      parent_id            INT4                 default 0,
      ancestors            VARCHAR(100)         null,
      dept_name            VARCHAR(50)          null,
      order_num            INT4                 default 0,
      leader               VARCHAR(50)          null,
      phone                VARCHAR(50)          null,
      email                VARCHAR(50)          null,
      status               BOOL                 default true,
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      remark               VARCHAR(1000)        null,
      constraint PK_SYS_DEPT primary key (dept_id)
);
comment on table sys_dept is '部门表';
comment on column sys_dept.dept_id is '部门id';
comment on column sys_dept.parent_id is '父部门id';
comment on column sys_dept.ancestors is '祖级列表';
comment on column sys_dept.dept_name is '部门名称';
comment on column sys_dept.order_num is '显示顺序';
comment on column sys_dept.leader is '负责人';
comment on column sys_dept.phone is '联系电话';
comment on column sys_dept.email is '邮箱';
comment on column sys_dept.status is '部门状态（true正常；false停用）';
comment on column sys_dept.create_by is '创建者';
comment on column sys_dept.create_time is '创建时间';
comment on column sys_dept.update_by is '更新者';
comment on column sys_dept.update_time is '更新时间';
comment on column sys_dept.remark is '备注';
SELECT setval('sys_dept_dept_id_seq', 200, true);
-- ----------------------------
-- 初始化-部门表数据
-- ----------------------------
insert into sys_dept values(100,  0,   '0',          'xx公司',   0, '', '', '', true,  'admin', now(), '', null),
                           (101,  100, '0,100',      '研发部', 1, '', '', '', true,  'admin', now(), '', null),
                           (102,  100, '0,100',      '产品部', 2, '', '', '', true,  'admin', now(), '', null),
                           (103,  100, '0,100',      '项目部', 3, '', '', '', true,  'admin', now(), '', null),
                           (104,  100, '0,100',      '数据部', 4, '', '', '', true,  'admin', now(), '', null),
                           (105,  100, '0,100',      '财务部', 5, '', '', '', true,  'admin', now(), '', null),
                           (106,  100, '0,100',      '人事部', 6, '', '', '', true,  'admin', now(), '', null),
                           (107,  100, '0,100',      '市场部', 7, '', '', '', true,  'admin', now(), '', null),
                           (108,  100, '0,100',      '销售部', 8, '', '', '', true,  'admin', now(), '', null);

-- ----------------------------
-- 用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user (
      user_id              VARCHAR(100)               not null,
      dept_id              INT4                 null,
      user_name            VARCHAR(100)         not null,
      nick_name            VARCHAR(100)         not null,
      user_type            VARCHAR(100)         null,
      email                VARCHAR(100)         null,
      phonenumber          VARCHAR(100)         null,
      sex                  INT2                 default 0,
      avatar               VARCHAR(255)         null,
      password             VARCHAR(100)         null,
      status               BOOL                 default true,
      login_ip             VARCHAR(125)         null,
      login_date           TIMESTAMP            null,
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      remark               VARCHAR(1000)        null,
      constraint PK_SYS_USER primary key (user_id)
);

comment on table sys_user is '用户信息表';
comment on column sys_user.user_id is '用户ID';
comment on column sys_user.dept_id is '部门ID';
comment on column sys_user.user_name is '用户账号';
comment on column sys_user.nick_name is '用户昵称';
comment on column sys_user.user_type is '用户类型（00系统用户）';
comment on column sys_user.email is '用户邮箱';
comment on column sys_user.phonenumber is '手机号码';
comment on column sys_user.sex is '用户性别（0男 1女 2未知）';
comment on column sys_user.avatar is '头像地址';
comment on column sys_user.password is '密码';
comment on column sys_user.status is '帐号状态（true正常 false停用）';
comment on column sys_user.login_ip is '最后登录IP';
comment on column sys_user.login_date is '最后登录时间';
comment on column sys_user.create_by is '创建者';
comment on column sys_user.create_time is '创建时间';
comment on column sys_user.update_by is '更新者';
comment on column sys_user.update_time is '更新时间';
comment on column sys_user.remark is '备注';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
insert into sys_user values('1',  101, 'admin', '超级管理员', '00', 'lqkj@you07.com', '13888888888', '1', '', '$2a$10$Sh7bZPuQ/qQOas5kk8iL2e8whSR7z57VF8MTMrav2ks0HKaXmFbY6', true,  '127.0.0.1', now(), 'admin', now(), '', null, '管理员');


-- ----------------------------
-- 岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post (
      post_id              SERIAL               not null,
      post_code            VARCHAR(100)         not null,
      post_name            VARCHAR(100)         not null,
      post_sort            INT4                 default 0,
      status               BOOL                 default true,
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      remark               VARCHAR(1000)        null,
      constraint PK_SYS_POST primary key (post_id)
);
comment on table sys_post is '岗位信息表';
comment on column sys_post.post_id is '岗位ID';
comment on column sys_post.post_code is '岗位编码';
comment on column sys_post.post_name is '岗位名称';
comment on column sys_post.post_sort is '显示顺序';
comment on column sys_post.status is '状态（true正常；false停用）';
comment on column sys_post.create_by is '创建者';
comment on column sys_post.create_time is '创建时间';
comment on column sys_post.update_by is '更新者';
comment on column sys_post.update_time is '更新时间';
comment on column sys_post.remark is '备注';
SELECT setval('sys_post_post_id_seq', 100, true);
-- ----------------------------
-- 初始化-岗位信息表数据
-- ----------------------------
insert into sys_post values(1, 'ceo',  '董事长',    1, true, 'admin', now(), '', null, ''),
                           (2, 'pm',   '产品',  2, true, 'admin', now(), '', null, ''),
                           (3, 'dm',   '研发',  3, true, 'admin', now(), '', null, ''),
                           (5, 'se',   '项目',  4, true, 'admin', now(), '', null, ''),
                           (6, 'sd',   '销售',  5, true, 'admin', now(), '', null, ''),
                           (7, 'cfo',   '财务',  6, true, 'admin', now(), '', null, ''),
                           (8, 'hr',   '人力资源',  7, true, 'admin', now(), '', null, ''),
                           (9, 'user', '普通员工',  8, true, 'admin', now(), '', null, '');


-- ----------------------------
-- 角色信息表
-- ----------------------------
drop table if exists sys_role;
create table sys_role (
      role_id              SERIAL               not null,
      role_name            VARCHAR(100)         not null,
      role_key             VARCHAR(100)         not null,
      role_sort            INT4                 default 0,
      data_scope           INT2                 default 1,
      menu_check_strictly  BOOL                 default false,
      dept_check_strictly  BOOL                 default false,
      status               BOOL                 default true,
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      remark               VARCHAR(1000)        null,
      constraint PK_SYS_ROLE primary key (role_id)
);

comment on table sys_role is '角色信息表';
comment on column sys_role.role_id is '角色ID';
comment on column sys_role.role_name is '角色名称';
comment on column sys_role.role_key is '角色权限字符串';
comment on column sys_role.role_sort is '显示顺序';
comment on column sys_role.data_scope is '数据范围（1：全部数据权限 2：自定数据权限 3：本部门数据权限 4：本部门及以下数据权限）';
comment on column sys_role.menu_check_strictly is '菜单树选择项是否关联显示';
comment on column sys_role.dept_check_strictly is '部门树选择项是否关联显示';
comment on column sys_role.status is '角色状态（true正常；false停用）';
comment on column sys_role.create_by is '创建者';
comment on column sys_role.create_time is '创建时间';
comment on column sys_role.update_by is '更新者';
comment on column sys_role.update_time is '更新时间';
comment on column sys_role.remark is '备注';
SELECT setval('sys_role_role_id_seq', 100, true);
-- ----------------------------
-- 初始化-角色信息表数据
-- ----------------------------
insert into sys_role values('1', '超级管理员',  'admin',  1, 1, false, false, true,  'admin', now(), '', null, '超级管理员');
insert into sys_role values('2', '普通角色',    'common', 2, 2, false, false, true,  'admin', now(), '', null, '普通角色');


-- ----------------------------
-- 菜单权限表
-- ----------------------------
drop table if exists sys_menu;
create table sys_menu (
      menu_id              SERIAL               not null,
      menu_name            VARCHAR(100)         not null,
      parent_id            INT4                 default 0,
      order_num            INT4                 default 0,
      path                 VARCHAR(255)         null,
      component            VARCHAR(255)         null,
      query                VARCHAR(255)         null,
      is_frame             BOOL                 default false,
      is_cache             BOOL                 default true,
      menu_type            CHAR                 null,
      visible              BOOL                 default true,
      status               BOOL                 default true,
      perms                VARCHAR(200)         null,
      icon                 VARCHAR(200)         default '#',
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      remark               VARCHAR(1000)        null,
      constraint PK_SYS_MENU primary key (menu_id)
);
comment on table sys_menu is '菜单权限表';
comment on column sys_menu.menu_id is '菜单ID';
comment on column sys_menu.menu_name is '菜单名称';
comment on column sys_menu.parent_id is '父菜单ID';
comment on column sys_menu.order_num is '显示顺序';
comment on column sys_menu.path is '路由地址';
comment on column sys_menu.component is '组件路径';
comment on column sys_menu.query is'路由参数';
comment on column sys_menu.is_frame is '是否为外链（true是 false否）';
comment on column sys_menu.is_cache is '是否缓存（true缓存 false不缓存）';
comment on column sys_menu.menu_type is '菜单类型（M目录 C菜单 F按钮）';
comment on column sys_menu.visible is'菜单状态（true显示 false隐藏）';
comment on column sys_menu.status is '菜单状态（true正常 false停用）';
comment on column sys_menu.perms is '权限标识';
comment on column sys_menu.icon is '菜单图标';
comment on column sys_menu.create_by is '创建者';
comment on column sys_menu.create_time is '创建时间';
comment on column sys_menu.update_by is '更新者';
comment on column sys_menu.update_time is '更新时间';
comment on column sys_menu.remark is '备注';
SELECT setval('sys_menu_menu_id_seq', 2000, true);
-- ----------------------------
-- 初始化-菜单信息表数据
-- ----------------------------
-- 一级菜单
insert into sys_menu values('1', '系统管理', '0', '1', 'system',           null, '', false, true, 'M', true, true, '', 'system',   'admin', now(), '', null, '系统管理目录');
insert into sys_menu values('2', '系统监控', '0', '2', 'monitor',          null, '', false, true, 'M', true, true, '', 'monitor',  'admin', now(), '', null, '系统监控目录');
insert into sys_menu values('3', '系统工具', '0', '3', 'tool',             null, '', false, true, 'M', true, true, '', 'tool',     'admin', now(), '', null, '系统工具目录');
insert into sys_menu values('4', '常用示例', '0', '4', 'case',             null, '', false, true, 'M', true, true, '', 'example',  'admin', now(), '', null, '常用示例目录');
insert into sys_menu values('5', '业务中心', '0', '5', 'business',             null, '', false, true, 'M', true, true, '', 'international',  'admin', now(), '', null, '常用示例目录');

-- 二级菜单
insert into sys_menu values('100',  '用户管理', '1',   '1', 'user',       'system/user/index',        '', false, true, 'C', true, true, 'system:user:list',        'user',          'admin', now(), '', null, '用户管理菜单');
insert into sys_menu values('101',  '角色管理', '1',   '2', 'role',       'system/role/index',        '', false, true, 'C', true, true, 'system:role:list',        'peoples',       'admin', now(), '', null, '角色管理菜单');
insert into sys_menu values('102',  '菜单管理', '1',   '3', 'menu',       'system/menu/index',        '', false, true, 'C', true, true, 'system:menu:list',        'tree-table',    'admin', now(), '', null, '菜单管理菜单');
insert into sys_menu values('103',  '部门管理', '1',   '4', 'dept',       'system/dept/index',        '', false, true, 'C', true, true, 'system:dept:list',        'tree',          'admin', now(), '', null, '部门管理菜单');
insert into sys_menu values('104',  '岗位管理', '1',   '5', 'post',       'system/post/index',        '', false, true, 'C', true, true, 'system:post:list',        'post',          'admin', now(), '', null, '岗位管理菜单');
insert into sys_menu values('105',  '字典管理', '1',   '6', 'dict',       'system/dict/index',        '', false, true, 'C', true, true, 'system:dict:list',        'dict',          'admin', now(), '', null, '字典管理菜单');
insert into sys_menu values('106',  '参数设置', '1',   '7', 'config',     'system/config/index',      '', false, true, 'C', true, true, 'system:config:list',      'edit',          'admin', now(), '', null, '参数设置菜单');
insert into sys_menu values('107',  '通知公告', '5',   '1', 'notice',     'business/notice/index',      '', false, true, 'C', true, true, 'business:notice:list',  'message',       'admin', now(), '', null, '通知公告菜单');
insert into sys_menu values('108',  '日志管理', '1',   '9', 'log',        '',                         '', false, true, 'M', true, true, '',                        'log',           'admin', now(), '', null, '日志管理菜单');
insert into sys_menu values('110',  '定时任务', '2',   '2', 'job',        'monitor/job/index',        '', false, true, 'C', true, true, 'monitor:job:list',        'job',           'admin', now(), '', null, '定时任务菜单');
insert into sys_menu values('112',  '服务监控', '2',   '4', 'server',     'monitor/server/index',     '', false, true, 'C', true, true, 'monitor:server:list',     'server',        'admin', now(), '', null, '服务监控菜单');
insert into sys_menu values('113',  '缓存监控', '2',   '5', 'cache',      'monitor/cache/index',      '', false, true, 'C', true, true, 'monitor:cache:list',      'redis',         'admin', now(), '', null, '缓存监控菜单');
insert into sys_menu values('114',  '表单构建', '3',   '1', 'build',      'tool/build/index',         '', false, true, 'C', true, true, 'tool:build:list',         'build',         'admin', now(), '', null, '表单构建菜单');
insert into sys_menu values('115',  '代码生成', '3',   '2', 'gen',        'tool/gen/index',           '', false, true, 'C', true, true, 'tool:gen:list',           'code',          'admin', now(), '', null, '代码生成菜单');
insert into sys_menu values('116',  '系统接口', '3',   '3', 'swagger',    'tool/swagger/index',       '', false, true, 'C', true, true, 'tool:swagger:list',       'swagger',       'admin', now(), '', null, '系统接口菜单');
insert into sys_menu values('117',  '选择用户', '4',   '1', 'selectUser', 'case/selectUser/index',    '', false, true, 'C', true, true, 'case:selectUser:list',    'select',    'admin', now(), '', null, '选择用户菜单');
insert into sys_menu values('118',  '文件上传', '4',   '2', 'uploadFile', 'case/uploadFile/index',    '', false, true, 'C', true, true, 'case:uploadFile:list',    'upload',    'admin', now(), '', null, '文件上传菜单');
insert into sys_menu values('119',  '接口配置', '1',   '10', 'apiConfig',  'system/apiConfig/index',     '', false, true, 'C', true, true, 'system:apiConfig:list',   'icon',     'admin', now(), '', null, '接口生成菜单');
insert into sys_menu values('120',  '监控信息', '5',   '3', 'cameraInfo',  'business/cameraInfo/index',  '', false, true, 'C', true, true, 'business:cameraInfo:list',  'video-camera',       'admin', now(), '', null, '监控信息菜单');
insert into sys_menu values('121',  '信息分类', '5',   '4', 'cmsCategory', 'business/cmsCategory/index', '', false, true, 'C', true, true, 'business:cmsCategory:list', 'operation', 'admin', now(), '', null, '信息分类菜单');
insert into sys_menu values('122',  '信息管理', '5',   '5', 'cmsNews', 'business/cmsNews/index', '', false, true, 'C', true, true, 'business:cmsNews:list', 'tickets', 'admin', now(), '', null, '信息管理菜单');
insert into sys_menu values('123',  '设备分类', '5',   '6', 'deviceCategory', 'business/deviceCategory/index', '', false, true, 'C', true, true, 'business:deviceCategory:list', 'tree', 'admin', now(), '', null, '设备分类菜单');

-- 三级菜单
insert into sys_menu values('500',  '操作日志', '108', '1', 'operlog',    'monitor/operlog/index',    '', false, true, 'C', true, true, 'monitor:operlog:list',    'form',          'admin', now(), '', null, '操作日志菜单');
insert into sys_menu values('501',  '登录日志', '108', '2', 'logininfor', 'monitor/logininfor/index', '', false, true, 'C', true, true, 'monitor:logininfor:list', 'logininfor',    'admin', now(), '', null, '登录日志菜单');
-- 用户管理按钮
insert into sys_menu values('1001', '用户查询', '100', '1',  '', '', '', false, true, 'F', true, true, 'system:user:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1002', '用户新增', '100', '2',  '', '', '', false, true, 'F', true, true, 'system:user:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1003', '用户修改', '100', '3',  '', '', '', false, true, 'F', true, true, 'system:user:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1004', '用户删除', '100', '4',  '', '', '', false, true, 'F', true, true, 'system:user:remove',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1005', '用户导出', '100', '5',  '', '', '', false, true, 'F', true, true, 'system:user:export',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1006', '用户导入', '100', '6',  '', '', '', false, true, 'F', true, true, 'system:user:import',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1007', '重置密码', '100', '7',  '', '', '', false, true, 'F', true, true, 'system:user:resetPwd',       '#', 'admin', now(), '', null, '');
-- 角色管理按钮
insert into sys_menu values('1008', '角色查询', '101', '1',  '', '', '', false, true, 'F', true, true, 'system:role:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1009', '角色新增', '101', '2',  '', '', '', false, true, 'F', true, true, 'system:role:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1010', '角色修改', '101', '3',  '', '', '', false, true, 'F', true, true, 'system:role:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1011', '角色删除', '101', '4',  '', '', '', false, true, 'F', true, true, 'system:role:remove',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1012', '角色导出', '101', '5',  '', '', '', false, true, 'F', true, true, 'system:role:export',         '#', 'admin', now(), '', null, '');
-- 菜单管理按钮
insert into sys_menu values('1013', '菜单查询', '102', '1',  '', '', '', false, true, 'F', true, true, 'system:menu:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1014', '菜单新增', '102', '2',  '', '', '', false, true, 'F', true, true, 'system:menu:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1015', '菜单修改', '102', '3',  '', '', '', false, true, 'F', true, true, 'system:menu:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1016', '菜单删除', '102', '4',  '', '', '', false, true, 'F', true, true, 'system:menu:remove',         '#', 'admin', now(), '', null, '');
-- 部门管理按钮
insert into sys_menu values('1017', '部门查询', '103', '1',  '', '', '', false, true, 'F', true, true, 'system:dept:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1018', '部门新增', '103', '2',  '', '', '', false, true, 'F', true, true, 'system:dept:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1019', '部门修改', '103', '3',  '', '', '', false, true, 'F', true, true, 'system:dept:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1020', '部门删除', '103', '4',  '', '', '', false, true, 'F', true, true, 'system:dept:remove',         '#', 'admin', now(), '', null, '');
-- 岗位管理按钮
insert into sys_menu values('1021', '岗位查询', '104', '1',  '', '', '', false, true, 'F', true, true, 'system:post:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1022', '岗位新增', '104', '2',  '', '', '', false, true, 'F', true, true, 'system:post:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1023', '岗位修改', '104', '3',  '', '', '', false, true, 'F', true, true, 'system:post:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1024', '岗位删除', '104', '4',  '', '', '', false, true, 'F', true, true, 'system:post:remove',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1025', '岗位导出', '104', '5',  '', '', '', false, true, 'F', true, true, 'system:post:export',         '#', 'admin', now(), '', null, '');
-- 字典管理按钮
insert into sys_menu values('1026', '字典查询', '105', '1', '#', '', '', false, true, 'F', true, true, 'system:dict:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1027', '字典新增', '105', '2', '#', '', '', false, true, 'F', true, true, 'system:dict:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1028', '字典修改', '105', '3', '#', '', '', false, true, 'F', true, true, 'system:dict:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1029', '字典删除', '105', '4', '#', '', '', false, true, 'F', true, true, 'system:dict:remove',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1030', '字典导出', '105', '5', '#', '', '', false, true, 'F', true, true, 'system:dict:export',         '#', 'admin', now(), '', null, '');
-- 参数设置按钮
insert into sys_menu values('1031', '参数查询', '106', '1', '#', '', '', false, true, 'F', true, true, 'system:config:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1032', '参数新增', '106', '2', '#', '', '', false, true, 'F', true, true, 'system:config:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1033', '参数修改', '106', '3', '#', '', '', false, true, 'F', true, true, 'system:config:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1034', '参数删除', '106', '4', '#', '', '', false, true, 'F', true, true, 'system:config:remove',       '#', 'admin', now(), '', null, '');
insert into sys_menu values('1035', '参数导出', '106', '5', '#', '', '', false, true, 'F', true, true, 'system:config:export',       '#', 'admin', now(), '', null, '');

-- 通知公告按钮
insert into sys_menu values('1036', '公告查询', '107', '1', '#', '', '', false, true, 'F', true, true, 'business:notice:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1037', '公告新增', '107', '2', '#', '', '', false, true, 'F', true, true, 'business:notice:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1038', '公告修改', '107', '3', '#', '', '', false, true, 'F', true, true, 'business:notice:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1039', '公告删除', '107', '4', '#', '', '', false, true, 'F', true, true, 'business:notice:remove',       '#', 'admin', now(), '', null, '');
-- 操作日志按钮
insert into sys_menu values('1040', '操作查询', '500', '1', '#', '', '', false, true, 'F', true, true, 'monitor:operlog:query',      '#', 'admin', now(), '', null, '');
insert into sys_menu values('1041', '操作删除', '500', '2', '#', '', '', false, true, 'F', true, true, 'monitor:operlog:remove',     '#', 'admin', now(), '', null, '');
insert into sys_menu values('1042', '日志导出', '500', '4', '#', '', '', false, true, 'F', true, true, 'monitor:operlog:export',     '#', 'admin', now(), '', null, '');
-- 登录日志按钮
insert into sys_menu values('1043', '登录查询', '501', '1', '#', '', '', false, true, 'F', true, true, 'monitor:logininfor:query',   '#', 'admin', now(), '', null, '');
insert into sys_menu values('1044', '登录删除', '501', '2', '#', '', '', false, true, 'F', true, true, 'monitor:logininfor:remove',  '#', 'admin', now(), '', null, '');
insert into sys_menu values('1045', '日志导出', '501', '3', '#', '', '', false, true, 'F', true, true, 'monitor:logininfor:export',  '#', 'admin', now(), '', null, '');
-- 定时任务按钮
insert into sys_menu values('1049', '任务查询', '110', '1', '#', '', '', false, true, 'F', true, true, 'monitor:job:query',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1050', '任务新增', '110', '2', '#', '', '', false, true, 'F', true, true, 'monitor:job:add',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1051', '任务修改', '110', '3', '#', '', '', false, true, 'F', true, true, 'monitor:job:edit',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1052', '任务删除', '110', '4', '#', '', '', false, true, 'F', true, true, 'monitor:job:remove',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1053', '状态修改', '110', '5', '#', '', '', false, true, 'F', true, true, 'monitor:job:changeStatus',   '#', 'admin', now(), '', null, '');
insert into sys_menu values('1054', '任务导出', '110', '7', '#', '', '', false, true, 'F', true, true, 'monitor:job:export',         '#', 'admin', now(), '', null, '');
-- 代码生成按钮
insert into sys_menu values('1055', '生成查询', '115', '1', '#', '', '', false, true, 'F', true, true, 'tool:gen:query',             '#', 'admin', now(), '', null, '');
insert into sys_menu values('1056', '生成修改', '115', '2', '#', '', '', false, true, 'F', true, true, 'tool:gen:edit',              '#', 'admin', now(), '', null, '');
insert into sys_menu values('1057', '生成删除', '115', '3', '#', '', '', false, true, 'F', true, true, 'tool:gen:remove',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1058', '导入代码', '115', '2', '#', '', '', false, true, 'F', true, true, 'tool:gen:import',            '#', 'admin', now(), '', null, '');
insert into sys_menu values('1059', '预览代码', '115', '4', '#', '', '', false, true, 'F', true, true, 'tool:gen:preview',           '#', 'admin', now(), '', null, '');
insert into sys_menu values('1060', '生成代码', '115', '5', '#', '', '', false, true, 'F', true, true, 'tool:gen:code',              '#', 'admin', now(), '', null, '');

--接口生成按钮
insert into sys_menu values('1061', '接口查询', '119', '1', '#', '', '', false, true, 'F', true, true, 'system:apiConfig:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1062', '接口新增', '119', '2', '#', '', '', false, true, 'F', true, true, 'system:apiConfig:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1063', '接口修改', '119', '3', '#', '', '', false, true, 'F', true, true, 'system:apiConfig:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1064', '接口删除', '119', '4', '#', '', '', false, true, 'F', true, true, 'system:apiConfig:remove',       '#', 'admin', now(), '', null, '');

-- 监控信息按钮 SQL
insert into sys_menu values('1065', '监控信息查询', '120', '1',  '#','', '', false, true, 'F', true, true, 'business:cameraInfo:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1066', '监控信息新增', '120', '2',  '#','', '', false, true, 'F', true, true, 'business:cameraInfo:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1067', '监控信息修改', '120', '3',  '#','', '', false, true, 'F', true, true, 'business:cameraInfo:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1068', '监控信息删除', '120', '4',  '#','', '', false, true, 'F', true, true, 'business:cameraInfo:remove',       '#', 'admin', now(), '', null, '');
insert into sys_menu values('1069', '监控信息导出', '120', '5',  '#','', '', false, true, 'F', true, true, 'business:cameraInfo:export',       '#', 'admin', now(), '', null, '');
insert into sys_menu values('1070', '获取监控流媒体地址', '120', '6',  '#', '','', false, true, 'F', true, true, 'business:cameraInfo:getCameraUrl',       '#', 'admin', now(), '', null, '');

--信息分类管理按钮
insert into sys_menu values('1071', '信息分类查询', '121', '1', '#', '', '', false, true, 'F', true, true, 'business:cmsCategory:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1072', '信息分类新增', '121', '2', '#', '', '', false, true, 'F', true, true, 'business:cmsCategory:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1073', '信息分类修改', '121', '3', '#', '', '', false, true, 'F', true, true, 'business:cmsCategory:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1074', '信息分类删除', '121', '4', '#', '', '', false, true, 'F', true, true, 'business:cmsCategory:remove',       '#', 'admin', now(), '', null, '');

--信息管理按钮
insert into sys_menu values('1075', '信息查询', '122', '1', '#', '', '', false, true, 'F', true, true, 'business:cmsNews:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1076', '信息新增', '122', '2', '#', '', '', false, true, 'F', true, true, 'business:cmsNews:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1077', '信息修改', '122', '3', '#', '', '', false, true, 'F', true, true, 'business:cmsNews:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1078', '信息删除', '122', '4', '#', '', '', false, true, 'F', true, true, 'business:cmsNews:remove',       '#', 'admin', now(), '', null, '');

--设备分类按钮
insert into sys_menu values('1079', '设备分类查询', '123', '1', '#', '', '', false, true, 'F', true, true, 'business:deviceCategory:query',        '#', 'admin', now(), '', null, '');
insert into sys_menu values('1080', '设备分类新增', '123', '2', '#', '', '', false, true, 'F', true, true, 'business:deviceCategory:add',          '#', 'admin', now(), '', null, '');
insert into sys_menu values('1081', '设备分类修改', '123', '3', '#', '', '', false, true, 'F', true, true, 'business:deviceCategory:edit',         '#', 'admin', now(), '', null, '');
insert into sys_menu values('1082', '设备分类删除', '123', '4', '#', '', '', false, true, 'F', true, true, 'business:deviceCategory:remove',       '#', 'admin', now(), '', null, '');

-- ----------------------------
-- 用户和角色关联表  用户N-1角色
-- ----------------------------
drop table if exists sys_user_role;
create table sys_user_role (
       user_id              VARCHAR(100)                 not null,
       role_id              INT4                 not null,
       constraint PK_SYS_USER_ROLE primary key (user_id, role_id)
);

comment on table sys_user_role is '用户和角色关联表';
comment on column sys_user_role.user_id is '用户ID';
comment on column sys_user_role.role_id is '角色ID';
-- ----------------------------
-- 初始化-用户和角色关联表数据
-- ----------------------------
insert into sys_user_role values ('1', '1');


-- ----------------------------
-- 角色和菜单关联表  角色1-N菜单
-- ----------------------------
drop table if exists sys_role_menu;
create table sys_role_menu (
       role_id              INT4                 not null,
       menu_id              INT4                 not null,
       constraint PK_SYS_ROLE_MENU primary key (role_id, menu_id)
);
comment on table sys_role_menu is '角色和菜单关联表';
comment on column sys_role_menu.role_id is '角色ID';
comment on column sys_role_menu.menu_id is '菜单ID';

-- ----------------------------
-- 角色和部门关联表  角色1-N部门
-- ----------------------------
drop table if exists sys_role_dept;
create table sys_role_dept (
       role_id              INT4                 not null,
       dept_id              INT4                 not null,
       constraint PK_SYS_ROLE_DEPT primary key (role_id, dept_id)
);
comment on table sys_role_dept is '角色和部门关联表';
comment on column sys_role_dept.role_id is '角色ID';
comment on column sys_role_dept.dept_id is '部门ID';



-- ----------------------------
-- 用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post (
       user_id              VARCHAR(100)                 not null,
       post_id              INT4                 not null,
       constraint PK_SYS_USER_POST primary key (user_id, post_id)
);
comment on table sys_user_post is '用户和岗位关联表';
comment on column sys_user_post.user_id is '用户ID';
comment on column sys_user_post.post_id is '岗位ID';
-- ----------------------------
-- 初始化-用户与岗位关联表数据
-- ----------------------------
insert into sys_user_post values ('1', '1');


-- ----------------------------
-- 操作日志记录
-- ----------------------------
drop table if exists sys_oper_log;
create table sys_oper_log (
      oper_id              BIGSERIAL            not null,
      title                VARCHAR(100)         null,
      business_type        INT2                 null,
      method               VARCHAR(100)         null,
      request_method       VARCHAR(20)          null,
      operator_type        INT2                 null,
      oper_name            VARCHAR(100)         null,
      dept_name            VARCHAR(100)         null,
      oper_url             VARCHAR(255)         null,
      oper_ip              VARCHAR(128)         null,
      oper_location        VARCHAR(255)         null,
      oper_param           TEXT                 null,
      json_result          TEXT                 null,
      status               BOOL                 null,
      error_msg            TEXT                 null,
      oper_time            TIMESTAMP            null,
      constraint PK_SYS_OPER_LOG primary key (oper_id)
);
comment on table sys_oper_log is '操作日志记录';
comment on column sys_oper_log.oper_id is '日志主键';
comment on column sys_oper_log.title is '模块标题';
comment on column sys_oper_log.business_type is '业务类型（0其它 1新增 2修改 3删除）';
comment on column sys_oper_log.method is '方法名称';
comment on column sys_oper_log.request_method is '请求方式';
comment on column sys_oper_log.operator_type is '操作类别（0其它 1后台用户 2手机端用户）';
comment on column sys_oper_log.oper_name is '操作人员';
comment on column sys_oper_log.dept_name is '部门名称';
comment on column sys_oper_log.oper_url is '请求URL';
comment on column sys_oper_log.oper_ip is '主机地址';
comment on column sys_oper_log.oper_location is '操作地点';
comment on column sys_oper_log.oper_param is '请求参数';
comment on column sys_oper_log.json_result is '返回参数';
comment on column sys_oper_log.status is '操作状态（true正常 false异常）';
comment on column sys_oper_log.error_msg is '错误消息';
comment on column sys_oper_log.oper_time is '操作时间';
SELECT setval('sys_oper_log_oper_id_seq', 100, true);

-- ----------------------------
-- 字典类型表
-- ----------------------------
drop table if exists sys_dict_type;
create table sys_dict_type (
       dict_id              SERIAL               not null,
       dict_name            VARCHAR(100)         null,
       dict_type            VARCHAR(100)         null,
       status               BOOL                 null,
       create_by            VARCHAR(100)         null,
       create_time          TIMESTAMP            null,
       update_by            VARCHAR(100)         null,
       update_time          TIMESTAMP            null,
       remark               VARCHAR(1000)        null,
       constraint PK_SYS_DICT_TYPE primary key (dict_id)
);

comment on table sys_dict_type is '字典类型表';
comment on column sys_dict_type.dict_id is '字典主键';
comment on column sys_dict_type.dict_name is '字典名称';
comment on column sys_dict_type.dict_type is '字典类型';
comment on column sys_dict_type.status is '状态（true正常；false停用）';
comment on column sys_dict_type.create_by is '创建者';
comment on column sys_dict_type.create_time is '创建时间';
comment on column sys_dict_type.update_by is '更新者';
comment on column sys_dict_type.update_time is '更新时间';
comment on column sys_dict_type.remark is '备注';
SELECT setval('sys_dict_type_dict_id_seq', 100, true);

insert into sys_dict_type values(1,  '用户性别', 'sys_user_sex',        true, 'admin', now(), '', null, '用户性别列表');
insert into sys_dict_type values(2,  '菜单状态', 'sys_show_hide',       true, 'admin', now(), '', null, '菜单状态列表');
insert into sys_dict_type values(3,  '系统开关', 'sys_normal_disable',  true, 'admin', now(), '', null, '系统开关列表');
insert into sys_dict_type values(4,  '任务状态', 'sys_job_status',      true, 'admin', now(), '', null, '任务状态列表');
insert into sys_dict_type values(5,  '任务分组', 'sys_job_group',       true, 'admin', now(), '', null, '任务分组列表');
insert into sys_dict_type values(6,  '系统是否', 'sys_yes_no',          true, 'admin', now(), '', null, '系统是否列表');
insert into sys_dict_type values(7,  '通知类型', 'sys_notice_type',     true, 'admin', now(), '', null, '通知类型列表');
insert into sys_dict_type values(8,  '通知状态', 'sys_notice_status',   true, 'admin', now(), '', null, '通知状态列表');
insert into sys_dict_type values(9,  '操作类型', 'sys_oper_type',       true, 'admin', now(), '', null, '操作类型列表');
insert into sys_dict_type values(10, '系统状态', 'sys_common_status',   true, 'admin', now(), '', null, '登录状态列表');
insert into sys_dict_type values(11, '接口返回类型', 'sys_api_data_type',   true, 'admin', now(), '', null, '接口返回类型列表');
insert into sys_dict_type values(12, '信息分类类型', 'cms_category_type',   true, 'admin', now(), '', null, '信息分类类型列表');
insert into sys_dict_type values(13, '监控对接类型', 'camera_interface_type',   true, 'admin', now(), '', null, '监控对接类型列表');
insert into sys_dict_type values(14, '设备分类数据类型', 'device_category_data_type',   true, 'admin', now(), '', null, '设备分类数据类型列表');
-- ----------------------------
-- 字典数据表
-- ----------------------------
drop table if exists sys_dict_data;
create table sys_dict_data (
       dict_code            SERIAL               not null,
       dict_sort            INT4                 null,
       dict_label           VARCHAR(100)         null,
       dict_value           VARCHAR(100)         null,
       dict_type            VARCHAR(100)         null,
       css_class            VARCHAR(100)         null,
       list_class           VARCHAR(100)         null,
       is_default           BOOL                 default false,
       status               BOOL                 default true,
       create_by            VARCHAR(100)         null,
       create_time          TIMESTAMP            null,
       update_by            VARCHAR(100)         null,
       update_time          TIMESTAMP            null,
       remark               VARCHAR(1000)        null,
       constraint PK_SYS_DICT_DATA primary key (dict_code)
);
comment on table sys_dict_data is '字典数据表';
comment on column sys_dict_data.dict_code is '字典编码';
comment on column sys_dict_data.dict_sort is '字典排序';
comment on column sys_dict_data.dict_label is '字典标签';
comment on column sys_dict_data.dict_value is '字典键值';
comment on column sys_dict_data.dict_type is '字典类型';
comment on column sys_dict_data.css_class is '样式属性（其他样式扩展）';
comment on column sys_dict_data.list_class is '回显样式';
comment on column sys_dict_data.is_default is '是否默认（true是 false否）';
comment on column sys_dict_data.status is '状态（true正常；false停用）';
comment on column sys_dict_data.create_by is '创建者';
comment on column sys_dict_data.create_time is '创建时间';
comment on column sys_dict_data.update_by is '更新者';
comment on column sys_dict_data.update_time is '更新时间';
comment on column sys_dict_data.remark is '备注';
SELECT setval('sys_dict_data_dict_code_seq', 100, true);

insert into sys_dict_data values(1,  1,  '男',       '0',       'sys_user_sex',        '',   '',        true, true, 'admin', now(), '', null, '性别男');
insert into sys_dict_data values(2,  2,  '女',       '1',       'sys_user_sex',        '',   '',        false, true, 'admin', now(), '', null, '性别女');
insert into sys_dict_data values(3,  3,  '未知',     '2',       'sys_user_sex',        '',   '',        false, true, 'admin', now(), '', null, '性别未知');
insert into sys_dict_data values(4,  1,  '显示',     'true',       'sys_show_hide',       '',   'primary', true, true, 'admin', now(), '', null, '显示菜单');
insert into sys_dict_data values(5,  2,  '隐藏',     'false',       'sys_show_hide',       '',   'danger',  false, true, 'admin', now(), '', null, '隐藏菜单');
insert into sys_dict_data values(6,  1,  '正常',     'true',       'sys_normal_disable',  '',   'primary', true, true, 'admin', now(), '', null, '正常状态');
insert into sys_dict_data values(7,  2,  '停用',     'false',       'sys_normal_disable',  '',   'danger',  false, true, 'admin', now(), '', null, '停用状态');
insert into sys_dict_data values(8,  1,  '正常',     'true',       'sys_job_status',      '',   'primary', true, true, 'admin', now(), '', null, '正常状态');
insert into sys_dict_data values(9,  2,  '暂停',     'false',       'sys_job_status',      '',   'danger',  false, true, 'admin', now(), '', null, '停用状态');
insert into sys_dict_data values(10, 1,  '默认',     'DEFAULT', 'sys_job_group',       '',   '',        true, true, 'admin', now(), '', null, '默认分组');
insert into sys_dict_data values(11, 2,  '系统',     'SYSTEM',  'sys_job_group',       '',   '',        false, true, 'admin', now(), '', null, '系统分组');
insert into sys_dict_data values(12, 1,  '是',       'true',       'sys_yes_no',          '',   'primary', true, true, 'admin', now(), '', null, '系统默认是');
insert into sys_dict_data values(13, 2,  '否',       'false',       'sys_yes_no',          '',   'danger',  false, true, 'admin', now(), '', null, '系统默认否');
insert into sys_dict_data values(14, 1,  '公开公示',     '1',       'sys_notice_type',     '',   'warning', true, true, 'admin', now(), '', null, '通知');
insert into sys_dict_data values(15, 2,  '政务信息',     '2',       'sys_notice_type',     '',   'success', false, true, 'admin', now(), '', null, '公告');
insert into sys_dict_data values(16, 1,  '正常',     '0',       'sys_notice_status',   '',   'primary', true, true, 'admin', now(), '', null, '正常状态');
insert into sys_dict_data values(17, 2,  '关闭',     '1',       'sys_notice_status',   '',   'danger',  false, true, 'admin', now(), '', null, '关闭状态');
insert into sys_dict_data values(18, 1,  '新增',     '1',       'sys_oper_type',       '',   'info',    false, true, 'admin', now(), '', null, '新增操作');
insert into sys_dict_data values(19, 2,  '修改',     '2',       'sys_oper_type',       '',   'info',    false, true, 'admin', now(), '', null, '修改操作');
insert into sys_dict_data values(20, 3,  '删除',     '3',       'sys_oper_type',       '',   'danger',  false, true, 'admin', now(), '', null, '删除操作');
insert into sys_dict_data values(21, 4,  '授权',     '4',       'sys_oper_type',       '',   'primary', false, true, 'admin', now(), '', null, '授权操作');
insert into sys_dict_data values(22, 5,  '导出',     '5',       'sys_oper_type',       '',   'warning', false, true, 'admin', now(), '', null, '导出操作');
insert into sys_dict_data values(23, 6,  '导入',     '6',       'sys_oper_type',       '',   'warning', false, true, 'admin', now(), '', null, '导入操作');
insert into sys_dict_data values(24, 7,  '强退',     '7',       'sys_oper_type',       '',   'danger',  false, true, 'admin', now(), '', null, '强退操作');
insert into sys_dict_data values(25, 8,  '生成代码', '8',       'sys_oper_type',       '',   'warning', false, true, 'admin', now(), '', null, '生成操作');
insert into sys_dict_data values(26, 9,  '清空数据', '9',       'sys_oper_type',       '',   'danger',  false, true, 'admin', now(), '', null, '清空操作');
insert into sys_dict_data values(27, 1,  '成功',     'true',       'sys_common_status',   '',   'primary', false, true, 'admin', now(), '', null, '正常状态');
insert into sys_dict_data values(28, 2,  '失败',     'false',       'sys_common_status',   '',   'danger',  false, true, 'admin', now(), '', null, '停用状态');
insert into sys_dict_data values(29, 1,  '单对象',     'Map',       'sys_api_data_type',   '',   'primary',  false, true, 'admin', now(), '', null, '单对象');
insert into sys_dict_data values(30, 2,  '集合对象',   'List',       'sys_api_data_type',   '',   'warning',  false, true, 'admin', now(), '', null, '集合对象');
insert into sys_dict_data values(31, 1,  '列表',   '0',       'cms_category_type',   '',   'primary',  false, true, 'admin', now(), '', null, '列表');
insert into sys_dict_data values(32, 2,  '单页',   '1',       'cms_category_type',   '',   'success',  false, true, 'admin', now(), '', null, '单页');
insert into sys_dict_data values(33, 3,  '链接',   '2',       'cms_category_type',   '',   'warning',  false, true, 'admin', now(), '', null, '链接');
insert into sys_dict_data values(34, 1,  'RTSP/RTMP',   '0',       'camera_interface_type',   '',   'primary',  false, true, 'admin', now(), '', null, 'RTSP/RTMP');
insert into sys_dict_data values(35, 2,  '海康平台',   '1',       'camera_interface_type',   '',   'success',  false, true, 'admin', now(), '', null, '海康平台');
insert into sys_dict_data values(36, 3,  '宇视平台',   '2',       'camera_interface_type',   '',   'warning',  false, true, 'admin', now(), '', null, '宇视平台');
insert into sys_dict_data values(37, 4,  '大华平台',   '3',       'camera_interface_type',   '',   'danger',  false, true, 'admin', now(), '', null, '大华平台');
insert into sys_dict_data values(38, 5,  '萤石云平台',   '4',       'camera_interface_type',   '',   'info',  false, true, 'admin', now(), '', null, '萤石云平台');
insert into sys_dict_data values(39, 1,  '点',   '1',       'device_category_data_type',   '',   'info',  false, true, 'admin', now(), '', null, '点');
insert into sys_dict_data values(40, 2,  '线',   '2',       'device_category_data_type',   '',   'danger',  false, true, 'admin', now(), '', null, '线');
insert into sys_dict_data values(41, 3,  '面',   '3',       'device_category_data_type',   '',   'warning',  false, true, 'admin', now(), '', null, '面');


-- ----------------------------
-- 参数配置表
-- ----------------------------
drop table if exists sys_config;
create table sys_config (
    config_id            SERIAL               not null,
    config_name          VARCHAR(100)         null,
    config_key           VARCHAR(100)         null,
    config_value         VARCHAR(1000)        null,
    config_value_type    INT2                 null,
    config_type          BOOL                 default false,
    create_by            VARCHAR(100)         null,
    create_time          TIMESTAMP            null,
    update_by            VARCHAR(100)         null,
    update_time          TIMESTAMP            null,
    remark               VARCHAR(1000)        null,
    constraint PK_SYS_CONFIG primary key (config_id)
);
COMMENT ON COLUMN sys_config.config_id IS '参数主键';
COMMENT ON COLUMN sys_config.config_name IS '参数名称';
COMMENT ON COLUMN sys_config.config_key IS '参数键名';
COMMENT ON COLUMN sys_config.config_value IS '参数键值';
COMMENT ON COLUMN sys_config.config_value_type IS '参数类型（0文本，1图片）';
COMMENT ON COLUMN sys_config.config_type IS '系统内置（true是 false否）';
COMMENT ON COLUMN sys_config.create_by IS '创建者';
COMMENT ON COLUMN sys_config.create_time IS '创建时间';
COMMENT ON COLUMN sys_config.update_by IS '更新者';
COMMENT ON COLUMN sys_config.update_time IS '更新时间';
COMMENT ON COLUMN sys_config.remark IS '备注';
COMMENT ON TABLE sys_config IS '参数配置表';
SELECT setval('sys_config_config_id_seq', 100, true);

insert into sys_config values(1, '主框架页-默认皮肤样式名称',     'sys.index.skinName',            'skin-blue',  0,   true, 'admin', now(), '', null, '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow' );
insert into sys_config values(2, '用户管理-账号初始密码',         'sys.user.initPassword',         'a123456',   0,     true, 'admin', now(), '', null, '初始化密码 a123456' );
insert into sys_config values(3, '主框架页-侧边栏主题',           'sys.index.sideTheme',           'theme-dark', 0,   true, 'admin', now(), '', null, '深色主题theme-dark，浅色主题theme-light' );
insert into sys_config values(4, '账号自助-验证码开关',           'sys.account.captchaOnOff',      'false',     0,     true, 'admin', now(), '', null, '是否开启验证码功能（true开启，false关闭）');
insert into sys_config values(5, '账号自助-是否开启用户注册功能', 'sys.account.registerUser',      'false',      0,   true, 'admin', now(), '', null, '是否开启注册用户功能（true开启，false关闭）');
insert into sys_config values(6, '系统名称-网站title', 'sys.index.title',      '灵奇通用后台管理系统',         0, true, 'admin', now(), '', null, '系统名称-网站title');
insert into sys_config values(7, '登录页背景图', 'sys.index.background',      '',         1, true, 'admin', now(), '', null, '登录页背景图');
insert into sys_config values(8, '海康平台-Host', 'hik.camera.host',      '10.22.3.60:443',         0, true, 'admin', now(), '', null, '海康平台Host');
insert into sys_config values(9, '海康平台-appKey', 'hik.camera.appKey',      '23644070',         0, true, 'admin', now(), '', null, '海康平台-appKey');
insert into sys_config values(10, '海康平台-appSecret', 'hik.camera.appSecret',      'iTjN7VDYx9eNbPUEPiKw',         0, true, 'admin', now(), '', null, '海康平台-appSecret');
insert into sys_config values(11, '海康平台-httpProtocol', 'hik.camera.httpProtocol',      'https',         0, true, 'admin', now(), '', null, '海康平台-httpProtocol');
insert into sys_config values(12, '海康平台-requestBody', 'hik.camera.requestBody',      '{"cameraIndexCode":"#cameraIndexCode","streamType":1,"protocol":"hls","transmode":1 }',         0, true, 'admin', now(), '', null, '海康平台-requestBody');
insert into sys_config values(13, '宇视平台-host', 'uniview.camera.host',      'http://127.0.0.1:8888/VIID/',         0, true, 'admin', now(), '', null, '宇视平台-host,地址最后需要有/');
insert into sys_config values(14, '宇视平台-username', 'uniview.camera.username',      'admin',         0, true, 'admin', now(), '', null, '宇视平台-username');
insert into sys_config values(15, '宇视平台-password', 'uniview.camera.password',      '123456',         0, true, 'admin', now(), '', null, '宇视平台-password');
insert into sys_config values(16, '宇视平台-TSAddress', 'uniview.camera.TSAddress',      '127.0.0.1',         0, true, 'admin', now(), '', null, '宇视平台-TSAddress');
insert into sys_config values(17, '宇视平台-TSPort', 'uniview.camera.TSPort',      '80',         0, true, 'admin', now(), '', null, '宇视平台-TSPort');
insert into sys_config values(18, '视频流代理地址', 'camera.proxy.url',      'http://127.0.0.0.1/',         0, true, 'admin', now(), '', null, '视频流代理地址,地址最后需要有/');
-- ----------------------------
-- 系统访问记录
-- ----------------------------
drop table if exists sys_logininfor;
create table sys_logininfor (
        info_id              BIGSERIAL            not null,
        user_name            VARCHAR(100)         null,
        ipaddr               VARCHAR(128)         null,
        login_location       VARCHAR(255)         null,
        browser              VARCHAR(100)         null,
        os                   VARCHAR(100)         null,
        status               BOOL                 null,
        msg                  VARCHAR(255)         null,
        login_time           timestamp     null,
        constraint PK_SYS_LOGININFOR primary key (info_id)
);
COMMENT ON COLUMN sys_logininfor.info_id IS '访问ID';
COMMENT ON COLUMN sys_logininfor.user_name IS '用户账号';
COMMENT ON COLUMN sys_logininfor.ipaddr IS '登录IP地址';
COMMENT ON COLUMN sys_logininfor.login_location IS '登录地点';
COMMENT ON COLUMN sys_logininfor.browser IS '浏览器类型';
COMMENT ON COLUMN sys_logininfor.os IS '操作系统';
COMMENT ON COLUMN sys_logininfor.status IS '登录状态（true成功 false失败）';
COMMENT ON COLUMN sys_logininfor.msg IS '提示消息';
COMMENT ON COLUMN sys_logininfor.login_time IS '备注';
COMMENT ON TABLE sys_logininfor IS '系统访问记录';
SELECT setval('sys_logininfor_info_id_seq', 100, true);

-- ----------------------------
-- 定时任务调度表
-- ----------------------------
drop table if exists sys_job;
create table sys_job (
     job_id               SERIAL               not null,
     job_name             VARCHAR(64)          not null,
     job_group            VARCHAR(64)          not null,
     invoke_target        VARCHAR(500)         null,
     cron_expression      VARCHAR(255)         null,
     misfire_policy       char(1)                 null,
     concurrent           BOOL                 null,
     status               BOOL                 null,
     create_by            VARCHAR(100)         null,
     create_time          TIMESTAMP            null,
     update_by            VARCHAR(100)         null,
     update_time          TIMESTAMP            null,
     remark               VARCHAR(1000)        null,
     constraint PK_SYS_JOB primary key (job_id, job_name, job_group)
);

COMMENT ON COLUMN sys_job.job_id IS '任务ID';
COMMENT ON COLUMN sys_job.job_name IS '任务名称';
COMMENT ON COLUMN sys_job.job_group IS '任务组名';
COMMENT ON COLUMN sys_job.invoke_target IS '调用目标字符串';
COMMENT ON COLUMN sys_job.cron_expression IS 'cron执行表达式';
COMMENT ON COLUMN sys_job.misfire_policy IS '计划执行错误策略（1立即执行 2执行一次 3放弃执行）';
COMMENT ON COLUMN sys_job.concurrent IS '是否并发执行（true允许 false禁止）';
COMMENT ON COLUMN sys_job.status IS '状态（true正常 false暂停）';
COMMENT ON COLUMN sys_job.create_by IS '创建者';
COMMENT ON COLUMN sys_job.create_time IS '创建时间';
COMMENT ON COLUMN sys_job.update_by IS '更新者';
COMMENT ON COLUMN sys_job.update_time IS '更新时间';
COMMENT ON COLUMN sys_job.remark IS '备注';
COMMENT ON TABLE sys_job IS '定时任务调度表';
SELECT setval('sys_job_job_id_seq', 100, true);

insert into sys_job values(1, '系统默认（无参）', 'DEFAULT', 'lwTask.lwNoParams', '0/10 * * * * ?', 3, false, false, 'admin', now(), '', null, '');
insert into sys_job values(2, '系统默认（有参）', 'DEFAULT', 'lwTask.lwParams(''lw'')',  '0/15 * * * * ?', 3, false, false, 'admin', now(), '', null, '');
insert into sys_job values(3, '系统默认（多参）', 'DEFAULT', 'lwTask.lwMultipleParams(''r'', true, 2000L, 316.50D, 100)',  '0/20 * * * * ?', 3, false, false, 'admin', now(), '', null, '');
insert into sys_job values(4, '监控在线状态', 'DEFAULT', 'cameraOnlineTask.handleCameraOnline',  '* 0/10 * * * ?', 3, false, false, 'admin', now(), '', null, '');


-- ----------------------------
-- 定时任务调度日志表
-- ----------------------------
drop table if exists sys_job_log;

create table sys_job_log (
     job_log_id           BIGSERIAL            not null,
     job_name             VARCHAR(64)          not null,
     job_group            VARCHAR(64)          not null,
     invoke_target        VARCHAR(500)         not null,
     job_message          TEXT                 null,
     status               BOOL                 null,
     exception_info       TEXT                 null,
     create_time          TIMESTAMP            null,
     constraint PK_SYS_JOB_LOG primary key (job_log_id)
);

COMMENT ON COLUMN sys_job_log.job_log_id IS '任务日志ID';
COMMENT ON COLUMN sys_job_log.job_name IS '任务名称';
COMMENT ON COLUMN sys_job_log.job_group IS '任务组名';
COMMENT ON COLUMN sys_job_log.invoke_target IS '调用目标字符串';
COMMENT ON COLUMN sys_job_log.job_message IS '日志信息';
COMMENT ON COLUMN sys_job_log.status IS '执行状态（true正常 true失败）';
COMMENT ON COLUMN sys_job_log.exception_info IS '异常信息';
COMMENT ON COLUMN sys_job_log.create_time IS '创建时间';
COMMENT ON TABLE sys_job_log IS '定时任务调度日志表';

-- ----------------------------
-- 代码生成业务表
-- ----------------------------
drop table if exists gen_table;
create table gen_table (
       table_id             SERIAL               not null,
       table_name           VARCHAR(200)         null,
       table_comment        VARCHAR(500)         null,
       sub_table_name       VARCHAR(200)         default '',
       sub_table_fk_name    VARCHAR(200)         default '',
       class_name           VARCHAR(255)         default '',
       tpl_category         VARCHAR(200)         default 'crud',
       package_name         VARCHAR(200)         null,
       module_name          VARCHAR(200)         null,
       business_name        VARCHAR(50)          null,
       function_name        VARCHAR(100)         null,
       function_author      VARCHAR(50)          null,
       gen_type             INT2                 null,
       data_scope_type      INT2                 null,
       gen_path             VARCHAR(255)         null,
       options              TEXT                 null,
       create_by            VARCHAR(100)         null,
       create_time          TIMESTAMP            null,
       update_by            VARCHAR(100)         null,
       update_time          TIMESTAMP            null,
       remark               VARCHAR(1000)        null,
       constraint PK_GEN_TABLE primary key (table_id)
);
comment on table gen_table is '代码生成业务表';
comment on column gen_table.table_id is '编号';
comment on column gen_table.table_name is '表名称';
comment on column gen_table.table_comment is '表描述';
comment on column gen_table.sub_table_name is '关联子表的表名';
comment on column gen_table.sub_table_fk_name is '子表关联的外键名';
comment on column gen_table.class_name is '实体类名称';
comment on column gen_table.tpl_category is '使用的模板（crud单表操作 tree树表操作）';
comment on column gen_table.package_name is '生成包路径';
comment on column gen_table.module_name is '生成模块名';
comment on column gen_table.business_name is '生成业务名';
comment on column gen_table.function_name is '生成功能名';
comment on column gen_table.function_author is '生成功能作者';
comment on column gen_table.gen_type is '生成代码方式（0zip压缩包 1自定义路径）';
comment on column gen_table.data_scope_type is '数据授权方式（0用户 1部门 2用户和部门）';
comment on column gen_table.gen_path is '生成路径（不填默认项目路径）';
comment on column gen_table.options is '其它生成选项';
comment on column gen_table.create_by is '创建者';
comment on column gen_table.create_time is '创建时间';
comment on column gen_table.update_by is '更新者';
comment on column gen_table.update_time is '更新时间';
comment on column gen_table.remark is '备注';


-- ----------------------------
-- 代码生成业务表字段
-- ----------------------------
drop table if exists gen_table_column;
create table gen_table_column (
      column_id            SERIAL               not null,
      table_id             INT4                 null,
      column_name          VARCHAR(200)         null,
      column_comment       VARCHAR(500)         null,
      column_type          VARCHAR(100)         null,
      java_type            VARCHAR(500)         null,
      java_field           VARCHAR(200)         null,
      is_pk                BOOL                 null,
      is_increment         BOOL                 null,
      is_required          BOOL                 null,
      is_insert            BOOL                 null,
      is_edit              BOOL                 null,
      is_list              BOOL                 null,
      is_query             BOOL                 null,
      query_type           VARCHAR(200)         null,
      html_type            VARCHAR(200)         null,
      dict_type            VARCHAR(200)         default '',
      order_num            INT4                 null,
      create_by            VARCHAR(100)         null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(100)         null,
      update_time          TIMESTAMP            null,
      constraint PK_GEN_TABLE_COLUMN primary key (column_id)
);

comment on table gen_table_column is '代码生成业务表字段';
comment on column gen_table_column.column_id is '编号';
comment on column gen_table_column.table_id is '归属表编号';
comment on column gen_table_column.column_name is '列名称';
comment on column gen_table_column.column_comment is '列描述';
comment on column gen_table_column.column_type is '列类型';
comment on column gen_table_column.java_type is 'JAVA类型';
comment on column gen_table_column.java_field is 'JAVA字段名';
comment on column gen_table_column.is_pk is '是否主键（true是 fasle否）';
comment on column gen_table_column.is_increment is '是否自增（true是 fasle否）';
comment on column gen_table_column.is_required is '是否必填（true是 fasle否）';
comment on column gen_table_column.is_insert is '是否为插入字段（true是 fasle否）';
comment on column gen_table_column.is_edit is '是否编辑字段（true是 fasle否）';
comment on column gen_table_column.is_list is '是否列表字段（true是 fasle否）';
comment on column gen_table_column.is_query is '是否查询字段（true是 fasle否）';
comment on column gen_table_column.query_type is '查询方式（=、!=、>、>=、<、<=、Between、Like、左Like、右Like等）';
comment on column gen_table_column.html_type is '显示类型（文本框、文本域、隐藏域字段、单选下拉框、多选下拉框、复选框、单选框、日期控件等）';
comment on column gen_table_column.dict_type is '字典类型';
comment on column gen_table_column.order_num is '排序';
comment on column gen_table_column.create_by is '创建者';
comment on column gen_table_column.create_time is '创建时间';
comment on column gen_table_column.update_by is '更新者';
comment on column gen_table_column.update_time is '更新时间';


drop table if exists sys_notice;
create table sys_notice (
    notice_id         SERIAL         not null,
    notice_title      varchar(50)     not null,
    notice_type       char(1)         not null,
    notice_content    text        default null,
    video_url         varchar(100)    null,
    status            char(1)         default '0',
    create_by         varchar(64)     default '',
    create_time       timestamp       null,
    update_by         varchar(64)     default '',
    update_time       timestamp       null,
    remark            varchar(255)    default null,
    primary key (notice_id)
);
COMMENT ON COLUMN sys_notice.notice_id IS '公告ID';
COMMENT ON COLUMN sys_notice.notice_title IS '公告标题';
COMMENT ON COLUMN sys_notice.notice_type IS '公告类型（1通知 2公告）';
COMMENT ON COLUMN sys_notice.notice_content IS '公告内容';
COMMENT ON COLUMN sys_notice.video_url IS '视频地址';
COMMENT ON COLUMN sys_notice.status IS '公告状态（0正常 1关闭）';
COMMENT ON COLUMN sys_notice.create_by IS '创建者';
COMMENT ON COLUMN sys_notice.create_time IS '创建时间';
COMMENT ON COLUMN sys_notice.update_by IS '更新者';
COMMENT ON COLUMN sys_notice.update_time IS '更新时间';
COMMENT ON COLUMN sys_notice.remark IS '备注';
COMMENT ON TABLE sys_notice IS '通知公告表';
SELECT setval('sys_notice_notice_id_seq', 10, true);



drop table if exists sys_api_config;

/*==============================================================*/
/* Table: sys_api_config                                        */
/*==============================================================*/
create table sys_api_config (
        id                   VARCHAR(64)          not null,
        route_path           VARCHAR(255)         null,
        name                 VARCHAR(255)         null,
        return_data_type     VARCHAR(10)          null,
        sql_str              TEXT                 null,
        param_example        TEXT                 null,
        create_by            VARCHAR(50)          null,
        create_time          TIMESTAMP            null,
        update_by            VARCHAR(50)          null,
        update_time          TIMESTAMP            null,
        remark               TEXT                 null,
        constraint PK_SYS_API_CONFIG primary key (id)
);

comment on table sys_api_config is
'查询接口配置';

comment on column sys_api_config.id is
'主键';

comment on column sys_api_config.route_path is
'接口路由';

comment on column sys_api_config.name is
'接口名称';

comment on column sys_api_config.return_data_type is
'返回类型';

comment on column sys_api_config.sql_str is
'SQL脚本';

comment on column sys_api_config.param_example is
'参数示例';

comment on column sys_api_config.create_by is
'创建人';

comment on column sys_api_config.create_time is
'创建时间';

comment on column sys_api_config.update_by is
'更新人';

comment on column sys_api_config.update_time is
'更新时间';

comment on column sys_api_config.remark is
'备注';



drop table IF EXISTS sys_camera_info;
create table sys_camera_info (
     camera_id            VARCHAR(50)          not null,
     name                 VARCHAR(100)         null,
     url                  VARCHAR(255)         null,
     camera_type          VARCHAR(50)          null,
     camera_index_code    VARCHAR(255)         null,
     online_status        BOOL                 null,
     create_by            VARCHAR(50)          null,
     create_time          TIMESTAMP            null,
     update_by            VARCHAR(50)          null,
     update_time          TIMESTAMP            null,
     constraint PK_sys_camera_info primary key (camera_id)
);

comment on table sys_camera_info is
'监控信息';

comment on column sys_camera_info.camera_id is
'监控编号';

comment on column sys_camera_info.name is
'监控名称';

comment on column sys_camera_info.url is
'监控地址';

comment on column sys_camera_info.camera_type is
'对接类型';

comment on column sys_camera_info.camera_index_code is
'相机编号';

comment on column sys_camera_info.online_status is
'在线状态';

comment on column sys_camera_info.create_by is
'创建人';

comment on column sys_camera_info.create_time is
'创建时间';

comment on column sys_camera_info.update_by is
'更新人';

comment on column sys_camera_info.update_time is
'更新时间';






drop table IF EXISTS cms_category;
create table cms_category (
      category_id          SERIAL               not null,
      parent_id            INT4                 null,
      ancestors            VARCHAR(255)         null,
      name                 VARCHAR(100)         null,
      category_type        INT4                 null,
      diy_url              VARCHAR(255)         null,
      order_num            INT4                 null,
      create_by            VARCHAR(50)          null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(50)          null,
      update_time          TIMESTAMP            null,
      remark               TEXT                 null,
      constraint PK_CMS_CATEGORY primary key (category_id)
);

comment on table cms_category is
'信息分类';

comment on column cms_category.category_id is
'编号';

comment on column cms_category.parent_id is
'所属父栏目';

comment on column cms_category.ancestors is
'祖级列表';

comment on column cms_category.name is
'名称';

comment on column cms_category.category_type is
'类型';

comment on column cms_category.diy_url is
'自定义链接';

comment on column cms_category.order_num is
'序号';

comment on column cms_category.create_by is
'创建人';

comment on column cms_category.create_time is
'创建时间';

comment on column cms_category.update_by is
'更新人';

comment on column cms_category.update_time is
'更新时间';

comment on column cms_category.remark is
'备注';


drop table IF EXISTS cms_news;
create table cms_news (
      news_id              VARCHAR(64)          not null,
      category_id          INT4                 null,
      title                VARCHAR(500)         null,
      content              TEXT                 null,
      view_count           INT4                 null,
      is_top               BOOL                 null,
      is_carousel             BOOL                 null,
      thumbnail            VARCHAR(255)         null,
      focus_imgs           JSONB                null,
      video_url            VARCHAR(255)         null,
      create_by            VARCHAR(50)          null,
      create_time          TIMESTAMP            null,
      update_by            VARCHAR(50)          null,
      update_time          TIMESTAMP            null,
      remark               TEXT                 null,
      constraint PK_CMS_NEWS primary key (news_id)
);

comment on table cms_news is
'信息详情';

comment on column cms_news.news_id is
'编号';

comment on column cms_news.category_id is
'所属分类';

comment on column cms_news.title is
'标题';

comment on column cms_news.content is
'内容';

comment on column cms_news.view_count is
'浏览量';

comment on column cms_news.is_top is
'是否置顶';

comment on column cms_news.is_carousel is
'是否轮播';

comment on column cms_news.thumbnail is
'缩略图';

comment on column cms_news.focus_imgs is
'轮播图';

comment on column cms_news.video_url is
'视频';

comment on column cms_news.create_by is
'创建人';

comment on column cms_news.create_time is
'创建时间';

comment on column cms_news.update_by is
'更新人';

comment on column cms_news.update_time is
'更新时间';

comment on column cms_news.remark is
'备注';

alter table cms_news
    add constraint FK_CMS_NEWS_REFERENCE_CMS_CATE foreign key (category_id)
        references cms_category (category_id)
        on delete cascade on update cascade;



drop table IF EXISTS device_category;

/*==============================================================*/
/* Table: device_category                                       */
/*==============================================================*/
create table device_category (
         category_id          SERIAL               not null,
         parent_id            INT4                 null,
         name                 VARCHAR(50)          null,
         default_icon         VARCHAR(255)         null,
         error_icon           VARCHAR(255)         null,
         selected_icon        VARCHAR(255)         null,
         min_zoom             INT4                 null,
         max_zoom             INT4                 null,
         data_type            INT4                 null,
         fill_color           VARCHAR(10)          null,
         border_color         VARCHAR(10)          null,
         width                INT4                 null,
         order_num            INT4                 null,
         preset               BOOL                 null,
         create_by            VARCHAR(50)          null,
         create_time          TIMESTAMP            null,
         update_by            VARCHAR(50)          null,
         update_time          TIMESTAMP            null,
         remark               TEXT                 null,
         constraint PK_DEVICE_CATEGORY primary key (category_id)
);

comment on table device_category is
'设备分类';

comment on column device_category.category_id is
'分类编号';

comment on column device_category.parent_id is
'父分类编号';

comment on column device_category.name is
'分类名称';

comment on column device_category.default_icon is
'默认图标';

comment on column device_category.error_icon is
'异常图标';

comment on column device_category.selected_icon is
'选中图标';

comment on column device_category.min_zoom is
'最小级数';

comment on column device_category.max_zoom is
'最大级数';

comment on column device_category.data_type is
'数据类型';

comment on column device_category.fill_color is
'填充色';

comment on column device_category.border_color is
'边框色';

comment on column device_category.width is
'宽度';

comment on column device_category.order_num is
'序号';

comment on column device_category.preset is
'预设分类';

comment on column device_category.create_by is
'创建人';

comment on column device_category.create_time is
'创建时间';

comment on column device_category.update_by is
'更新人';

comment on column device_category.update_time is
'更新时间';

comment on column device_category.remark is
'备注';
