/*==============================================================*/
/* DBMS name:      PostgreSQL 9.x                               */
/* Created on:     2024/11/13 11:07:23                          */
/*==============================================================*/


/*==============================================================*/
/* Table: area_info                                             */
/*==============================================================*/
create table area_info (
                           area_id              SERIAL               not null,
                           type_id              INT4                 not null,
                           area_name            VARCHAR(255)         null,
                           memo                 VARCHAR(255)         null,
                           colour               VARCHAR(255)         null,
                           acreage              INT4                 null,
                           location             jsonb                null,
                           constraint PK_AREA_INFO primary key (area_id)
);

comment on table area_info is
'区域对象';

comment on column area_info.area_id is
'区域id：area_id';

comment on column area_info.type_id is
'类别编号：type_id';

comment on column area_info.area_name is
'名字：area_name';

comment on column area_info.memo is
'备注：memo';

comment on column area_info.colour is
'颜色：colour';

comment on column area_info.acreage is
'面积：acreage';

comment on column area_info.location is
'坐标： location';

/*==============================================================*/
/* Table: area_type                                             */
/*==============================================================*/
create table area_type (
                           type_id              SERIAL               not null,
                           parent_id            INT4                 null,
                           type_name            VARCHAR(255)         null,
                           click                BOOL                 null,
                           search               BOOL                 null,
                           description          VARCHAR(255)         null,
                           order_id             INT4                 null,
                           memo                 VARCHAR(255)         null,
                           colour               VARCHAR(255)         null,
                           constraint PK_AREA_TYPE primary key (type_id)
);

comment on table area_type is
'区域类型：area_type';

comment on column area_type.type_id is
'类别id：type_id';

comment on column area_type.parent_id is
'父类型编号：parent_id';

comment on column area_type.type_name is
'类别名称：type_name';

comment on column area_type.click is
'是否可点击：click';

comment on column area_type.search is
'是否可搜索：search';

comment on column area_type.description is
'类别描述：description';

comment on column area_type.order_id is
'排序：order_id';

comment on column area_type.memo is
'备注：memo';

comment on column area_type.colour is
'颜色：colour';

/*==============================================================*/
/* Table: building_info                                         */
/*==============================================================*/
create table building_info (
                               building_id          SERIAL               not null,
                               type_id              INT4                 null,
                               building_name        VARCHAR(255)         null,
                               map_code             INT4                 null,
                               en_name              VARCHAR(255)         null,
                               alias                VARCHAR(255)         null,
                               order_id             INT4                 null,
                               syn_status           BOOL                 null,
                               delete               BOOL                 null,
                               brief                VARCHAR(255)         null,
                               lng_lat              VARCHAR(255)         null,
                               memo                 VARCHAR(255)         null,
                               raster_lng_lat       VARCHAR(255)         null,
                               address              VARCHAR(255)         null,
                               height               INT4                 null,
                               level_number         INT4                 null,
                               households           INT4                 null,
                               acreage              INT4                 null,
                               constraint PK_BUILDING_INFO primary key (building_id)
);

comment on table building_info is
'大楼信息';

comment on column building_info.building_id is
'大楼编号：building_id';

comment on column building_info.type_id is
'类型编号：type_id';

comment on column building_info.building_name is
'大楼名称：building_name';

comment on column building_info.map_code is
'地图编码：map_code';

comment on column building_info.en_name is
'英文名称：en_name';

comment on column building_info.alias is
'别名：alias';

comment on column building_info.order_id is
'排序：order_id';

comment on column building_info.syn_status is
'是否已同步：syn_status';

comment on column building_info.delete is
'是否删除：delete';

comment on column building_info.brief is
'简介：brief';

comment on column building_info.lng_lat is
'二维坐标：lng_lat';

comment on column building_info.memo is
'备注：memo';

comment on column building_info.raster_lng_lat is
'三维坐标：raster_lng_lat';

comment on column building_info.address is
'地址：address';

comment on column building_info.height is
'高度：height';

comment on column building_info.level_number is
'楼层数：level_number';

comment on column building_info.households is
'户数：households';

comment on column building_info.acreage is
'面积：acreage';

/*==============================================================*/
/* Table: building_type                                         */
/*==============================================================*/
create table building_type (
                               type_id              SERIAL               not null,
                               parent_id            INT4                 null,
                               type_name            VARCHAR(255)         null,
                               click                BOOL                 null,
                               search               BOOL                 null,
                               description          VARCHAR(255)         null,
                               order_id             INT4                 null,
                               memo                 VARCHAR(255)         null,
                               constraint PK_BUILDING_TYPE primary key (type_id)
);

comment on table building_type is
'大楼类别：building_type';

comment on column building_type.type_id is
'类别编号：type_id';

comment on column building_type.parent_id is
'父类型编号：parent_id';

comment on column building_type.type_name is
'Col类别名称：type_name';

comment on column building_type.click is
'是否可点击：click';

comment on column building_type.search is
'是否可搜索：search';

comment on column building_type.description is
'类别描述：description';

comment on column building_type.order_id is
'排序：order_id';

comment on column building_type.memo is
'备注：memo';

/*==============================================================*/
/* Table: developments                                          */
/*==============================================================*/
create table developments (
                              id                   SERIAL               not null,
                              content              VARCHAR(255)         null,
                              constraint PK_DEVELOPMENTS primary key (id)
);

comment on table developments is
'发展定位：developments';

comment on column developments.id is
'id';

comment on column developments.content is
'内容：content';

/*==============================================================*/
/* Table: elevator_info                                         */
/*==============================================================*/
create table elevator_info (
                               elevator_id          SERIAL               not null,
                               elevator_code        VARCHAR(255)         null,
                               building_id          INT4                 null,
                               status               INT4                 null,
                               elevator_name        VARCHAR(255)         null,
                               upkeep_num           INT4                 null,
                               constraint PK_ELEVATOR_INFO primary key (elevator_id)
);

comment on table elevator_info is
'电梯信息：elevator_info';

comment on column elevator_info.elevator_id is
'电梯id：elevator_id';

comment on column elevator_info.elevator_code is
'电梯型号：elevator_code';

comment on column elevator_info.building_id is
'大楼id：building_id';

comment on column elevator_info.status is
'电梯状态：status';

comment on column elevator_info.elevator_name is
'电梯名字：elevator_name';

comment on column elevator_info.upkeep_num is
'保养次数：upkeep_num';

/*==============================================================*/
/* Table: equipment_info                                        */
/*==============================================================*/
create table equipment_info (
                                equipment_id         SERIAL               not null,
                                type_id              INT4                 null,
                                room_id              INT4                 null,
                                building_id          INT4                 null,
                                area_id              INT4                 null,
                                equipment_name       VARCHAR(255)         null,
                                lng_lat              VARCHAR(255)         null,
                                raster_lng_lat       VARCHAR(255)         null,
                                type_name            VARCHAR(255)         null,
                                status               INT4                 null,
                                constraint PK_EQUIPMENT_INFO primary key (equipment_id)
);

comment on table equipment_info is
'设备信息';

comment on column equipment_info.equipment_id is
'设备id：equipment_id';

comment on column equipment_info.type_id is
'类别id：type_id';

comment on column equipment_info.room_id is
'房间编号：room_id';

comment on column equipment_info.building_id is
'大楼编号：building_id';

comment on column equipment_info.area_id is
'区域id：area_id';

comment on column equipment_info.equipment_name is
'名称：equipment_name';

comment on column equipment_info.lng_lat is
'二维坐标：lng_lat';

comment on column equipment_info.raster_lng_lat is
'三维坐标：raster_lng_lat';

comment on column equipment_info.type_name is
'类型名：type_name';

comment on column equipment_info.status is
'状态：status';

/*==============================================================*/
/* Table: equipment_type                                        */
/*==============================================================*/
create table equipment_type (
                                type_id              SERIAL               not null,
                                parent_id            INT4                 null,
                                type_name            VARCHAR(255)         null,
                                click                BOOL                 null,
                                search               BOOL                 null,
                                description          VARCHAR(255)         null,
                                order_id             INT4                 null,
                                memo                 VARCHAR(255)         null,
                                colour               VARCHAR(255)         null,
                                constraint PK_EQUIPMENT_TYPE primary key (type_id)
);

comment on table equipment_type is
'设备类型：equipment_type';

comment on column equipment_type.type_id is
'类别id：type_id';

comment on column equipment_type.parent_id is
'父类型编号：parent_id';

comment on column equipment_type.type_name is
'类别名称：type_name';

comment on column equipment_type.click is
'是否可点击：click';

comment on column equipment_type.search is
'是否可搜索：search';

comment on column equipment_type.description is
'类别描述：description';

comment on column equipment_type.order_id is
'排序：order_id';

comment on column equipment_type.memo is
'备注：memo';

comment on column equipment_type.colour is
'颜色：colour';

/*==============================================================*/
/* Table: forewarning_info                                      */
/*==============================================================*/
create table forewarning_info (
                                  forewarning_id       SERIAL               not null,
                                  forewarning_name     VARCHAR(255)         null,
                                  content              VARCHAR(255)         null,
                                  equipment_id         INT4                 null,
                                  equipment_name       VARCHAR(255)         null,
                                  create_time          TIMESTAMP            null,
                                  is_resolve           BOOL                 null,
                                  resolve_time         TIMESTAMP            null,
                                  constraint PK_FOREWARNING_INFO primary key (forewarning_id)
);

comment on table forewarning_info is
'预警信息';

comment on column forewarning_info.forewarning_id is
'预警id：forewarning_id';

comment on column forewarning_info.forewarning_name is
'预警标题：forewarning_name';

comment on column forewarning_info.content is
'内容：content';

comment on column forewarning_info.equipment_id is
'设备id：equipment_id';

comment on column forewarning_info.equipment_name is
'设备名：equipment_name';

comment on column forewarning_info.create_time is
'记录时间：create_time';

comment on column forewarning_info.is_resolve is
'是否解决：is_resolve';

comment on column forewarning_info.resolve_time is
'解决时间：resolve_time';

/*==============================================================*/
/* Table: house_type                                            */
/*==============================================================*/
create table house_type (
                            type_id              SERIAL               not null,
                            type_name            VARCHAR(255)         null,
                            url                  VARCHAR(255)         null,
                            memo                 VARCHAR(255)         null,
                            constraint PK_HOUSE_TYPE primary key (type_id)
);

comment on table house_type is
'户型信息：house_type';

comment on column house_type.type_id is
'户型id：house_type_id';

comment on column house_type.type_name is
'户型名：type_name';

comment on column house_type.url is
'户型图地址：url';

comment on column house_type.memo is
'备注：memo';

/*==============================================================*/
/* Table: light_info                                            */
/*==============================================================*/
create table light_info (
                            light_id             SERIAL               not null,
                            light_name           VARCHAR(255)         null,
                            geom                 geometry             null,
                            properties           jsonb                null,
                            constraint PK_LIGHT_INFO primary key (light_id)
);

comment on table light_info is
'灯光信息：light_info';

comment on column light_info.light_id is
'灯光ID：light_id';

comment on column light_info.light_name is
'灯光名字：light_name';

comment on column light_info.geom is
'空间信息：geom';

comment on column light_info.properties is
'属性信息：properties';

/*==============================================================*/
/* Table: model_info                                            */
/*==============================================================*/
create table model_info (
                            model_id             SERIAL               not null,
                            model_name           VARCHAR(255)         null,
                            original_path        VARCHAR(255)         null,
                            model_icon           VARCHAR(255)         null,
                            constraint PK_MODEL_INFO primary key (model_id)
);

comment on table model_info is
'模型信息：model_info';

comment on column model_info.model_id is
'模型ID：model_id';

comment on column model_info.model_name is
'模型名称：model_name';

comment on column model_info.original_path is
'原始模型文件地址：original_path';

comment on column model_info.model_icon is
'模型图标文件地址：model_icon';

/*==============================================================*/
/* Table: organization_info                                     */
/*==============================================================*/
create table organization_info (
                                   organization_id      SERIAL               not null,
                                   type_id              INT4                 null,
                                   room_id              INT4                 null,
                                   building_id          INT4                 null,
                                   area_id              INT4                 null,
                                   organization_name    VARCHAR(255)         null,
                                   intro                VARCHAR(255)         null,
                                   lng_lat              VARCHAR(255)         null,
                                   raster_lng_lat       VARCHAR(255)         null,
                                   important            BOOL                 null,
                                   type_name            VARCHAR(255)         null,
                                   address              VARCHAR(255)         null,
                                   logo                 VARCHAR(255)         null,
                                   telephone            VARCHAR(255)         null,
                                   product              VARCHAR(255)         null,
                                   enter_time           TIMESTAMP            null,
                                   employe_num          INT4                 null,
                                   constraint PK_ORGANIZATION_INFO primary key (organization_id)
);

comment on table organization_info is
'主体信息';

comment on column organization_info.organization_id is
'主体id：organization_id';

comment on column organization_info.type_id is
'类别id：type_id';

comment on column organization_info.room_id is
'房间编号：room_id';

comment on column organization_info.building_id is
'大楼编号：building_id';

comment on column organization_info.area_id is
'区域id：area_id';

comment on column organization_info.organization_name is
'名称：organization_name';

comment on column organization_info.intro is
'简介：intro';

comment on column organization_info.lng_lat is
'二维坐标：lng_lat';

comment on column organization_info.raster_lng_lat is
'三维坐标：raster_lng_lat';

comment on column organization_info.important is
'是否重要：important';

comment on column organization_info.type_name is
'类型名：type_name';

comment on column organization_info.address is
'地址：address';

comment on column organization_info.logo is
'logo';

comment on column organization_info.telephone is
'联系方式：telephone';

comment on column organization_info.product is
'主要产品：product';

comment on column organization_info.enter_time is
'入驻时间：enter_time';

comment on column organization_info.employe_num is
'员工人数：employe_num';

/*==============================================================*/
/* Table: organization_type                                     */
/*==============================================================*/
create table organization_type (
                                   type_id              SERIAL               not null,
                                   parent_id            INT4                 null,
                                   type_name            VARCHAR(255)         null,
                                   click                BOOL                 null,
                                   search               BOOL                 null,
                                   description          VARCHAR(255)         null,
                                   order_id             INT4                 null,
                                   memo                 VARCHAR(255)         null,
                                   colour               VARCHAR(255)         null,
                                   constraint PK_ORGANIZATION_TYPE primary key (type_id)
);

comment on table organization_type is
'主体类型：organization_type';

comment on column organization_type.type_id is
'类别id：type_id';

comment on column organization_type.parent_id is
'父类型编号：parent_id';

comment on column organization_type.type_name is
'类别名称：type_name';

comment on column organization_type.click is
'是否可点击：click';

comment on column organization_type.search is
'是否可搜索：search';

comment on column organization_type.description is
'类别描述：description';

comment on column organization_type.order_id is
'排序：order_id';

comment on column organization_type.memo is
'备注：memo';

comment on column organization_type.colour is
'颜色：colour';

/*==============================================================*/
/* Table: plan_info                                             */
/*==============================================================*/
create table plan_info (
                           plan_id              SERIAL               not null,
                           area_id              INT4                 null,
                           type_id              INT4                 not null,
                           plan_name            VARCHAR(255)         null,
                           content              VARCHAR(255)         null,
                           colour               VARCHAR(255)         null,
                           acreage              INT4                 null,
                           constraint PK_PLAN_INFO primary key (plan_id)
);

comment on table plan_info is
'规划对象';

comment on column plan_info.plan_id is
'区域id：plan_id';

comment on column plan_info.type_id is
'类别编号：type_id';

comment on column plan_info.plan_name is
'名字：plan_name';

comment on column plan_info.content is
'备注：content';

comment on column plan_info.colour is
'颜色：colour';

comment on column plan_info.acreage is
'面积：acreage';

/*==============================================================*/
/* Table: plan_type                                             */
/*==============================================================*/
create table plan_type (
                           type_id              SERIAL               not null,
                           parent_id            INT4                 null,
                           type_name            VARCHAR(255)         null,
                           click                BOOL                 null,
                           search               BOOL                 null,
                           description          VARCHAR(255)         null,
                           order_id             INT4                 null,
                           memo                 VARCHAR(255)         null,
                           colour               VARCHAR(255)         null,
                           constraint PK_PLAN_TYPE primary key (type_id)
);

comment on table plan_type is
'规划类型：plan_type';

comment on column plan_type.type_id is
'类别id：type_id';

comment on column plan_type.parent_id is
'父类型编号：parent_id';

comment on column plan_type.type_name is
'类别名称：type_name';

comment on column plan_type.click is
'是否可点击：click';

comment on column plan_type.search is
'是否可搜索：search';

comment on column plan_type.description is
'类别描述：description';

comment on column plan_type.order_id is
'排序：order_id';

comment on column plan_type.memo is
'备注：memo';

comment on column plan_type.colour is
'颜色：colour';

/*==============================================================*/
/* Table: policy_info                                           */
/*==============================================================*/
create table policy_info (
                             policy_id            SERIAL               not null,
                             policy_name          VARCHAR(255)         null,
                             url                  VARCHAR(255)         null,
                             create_time          TIMESTAMP            null,
                             constraint PK_POLICY_INFO primary key (policy_id)
);

comment on table policy_info is
'政策信息';

comment on column policy_info.policy_id is
'政策id：policy_id';

comment on column policy_info.policy_name is
'政策名称：policy_name';

comment on column policy_info.url is
'政策文件地址：url';

comment on column policy_info.create_time is
'发布日期：create_time';

/*==============================================================*/
/* Table: room_info                                             */
/*==============================================================*/
create table room_info (
                           room_id              SERIAL               not null,
                           type_id              INT4                 null,
                           building_id          INT4                 null,
                           house_type_id        INT4                 null,
                           room_name            VARCHAR(255)         null,
                           map_code             INT4                 null,
                           en_name              VARCHAR(255)         null,
                           alias                VARCHAR(255)         null,
                           order_id             INT4                 null,
                           syn_status           BOOL                 null,
                           delete               BOOL                 null,
                           brief                VARCHAR(255)         null,
                           lng_lat              VARCHAR(255)         null,
                           raster_lng_lat       VARCHAR(255)         null,
                           memo                 VARCHAR(255)         null,
                           address              VARCHAR(255)         null,
                           level_number         INT4                 null,
                           acreage              INT4                 null,
                           building_name        VARCHAR(255)         null,
                           hourse_number        VARCHAR(255)         null,
                           constraint PK_ROOM_INFO primary key (room_id)
);

comment on table room_info is
'房间信息：room_info';

comment on column room_info.room_id is
'房间编号：room_id';

comment on column room_info.type_id is
'类型编号：type_id';

comment on column room_info.building_id is
'大楼编码：building_id';

comment on column room_info.house_type_id is
'户型id：house_type_id';

comment on column room_info.room_name is
'房间名称：room_name';

comment on column room_info.map_code is
'地图编码：map_code';

comment on column room_info.en_name is
'英文名称：en_name';

comment on column room_info.alias is
'别名：alias';

comment on column room_info.order_id is
'排序：order_id';

comment on column room_info.syn_status is
'是否已同步：syn_status';

comment on column room_info.delete is
'是否删除：delete';

comment on column room_info.brief is
'简介：brief';

comment on column room_info.lng_lat is
'二维坐标：lng_lat';

comment on column room_info.raster_lng_lat is
'三维坐标：raster_lng_lat';

comment on column room_info.memo is
'备注：memo';

comment on column room_info.address is
'地址：address';

comment on column room_info.level_number is
'楼层编码：leaf';

comment on column room_info.acreage is
'面积：acreage';

comment on column room_info.building_name is
'大楼名称：building_name';

comment on column room_info.hourse_number is
'门牌号：hourse_number';

/*==============================================================*/
/* Table: room_type                                             */
/*==============================================================*/
create table room_type (
                           type_id              SERIAL               not null,
                           parent_id            INT4                 null,
                           type_name            VARCHAR(255)         null,
                           click                BOOL                 null,
                           search               BOOL                 null,
                           description          VARCHAR(255)         null,
                           order_id             INT4                 null,
                           memo                 VARCHAR(255)         null,
                           constraint PK_ROOM_TYPE primary key (type_id)
);

comment on table room_type is
'房间类别：room_type';

comment on column room_type.type_id is
'类别编号：type_id';

comment on column room_type.parent_id is
'父类型编号：parent_id';

comment on column room_type.type_name is
'类别名称：type_name';

comment on column room_type.click is
'是否可点击：click';

comment on column room_type.search is
'是否可搜索：search';

comment on column room_type.description is
'类别描述：description';

comment on column room_type.order_id is
'排序：order_id';

comment on column room_type.memo is
'备注：memo';

/*==============================================================*/
/* Table: station_info                                          */
/*==============================================================*/
create table station_info (
                              station_id           SERIAL               not null,
                              station_name         VARCHAR(255)         null,
                              memo                 VARCHAR(255)         null,
                              lng_lat              VARCHAR(255)         null,
                              raster_lng_lat       VARCHAR(255)         null,
                              traffic_id           int4                 null,
                              constraint PK_STATION_INFO primary key (station_id)
);

comment on table station_info is
'站点信息';

comment on column station_info.station_id is
'站点id：station_id';

comment on column station_info.station_name is
'站点名称：station_name';

comment on column station_info.memo is
'备注：memo';

comment on column station_info.lng_lat is
'二维坐标：lng_lat';

comment on column station_info.raster_lng_lat is
'三维坐标：raster_lng_lat';

comment on column station_info.traffic_id is
'车辆id：traffic_id';

/*==============================================================*/
/* Table: traffic_info                                          */
/*==============================================================*/
create table traffic_info (
                              traffic_id           SERIAL               not null,
                              type_id              INT4                 not null,
                              traffic_name         VARCHAR(255)         null,
                              amount               INT4                 null,
                              memo                 VARCHAR(255)         null,
                              colour               VARCHAR(255)         null,
                              constraint PK_TRAFFIC_INFO primary key (traffic_id)
);

comment on table traffic_info is
'交通对象';

comment on column traffic_info.traffic_id is
'交通id：traffic_id';

comment on column traffic_info.type_id is
'类别编号：type_id';

comment on column traffic_info.traffic_name is
'名字：traffic_name';

comment on column traffic_info.amount is
'数量：amount';

comment on column traffic_info.memo is
'备注：memo';

comment on column traffic_info.colour is
'颜色：colour';

/*==============================================================*/
/* Table: traffic_type                                          */
/*==============================================================*/
create table traffic_type (
                              type_id              SERIAL               not null,
                              parent_id            INT4                 null,
                              type_name            VARCHAR(255)         null,
                              click                BOOL                 null,
                              search               BOOL                 null,
                              description          VARCHAR(255)         null,
                              order_id             INT4                 null,
                              memo                 VARCHAR(255)         null,
                              colour               VARCHAR(255)         null,
                              constraint PK_TRAFFIC_TYPE primary key (type_id)
);

comment on table traffic_type is
'交通类型：traffic_type';

comment on column traffic_type.type_id is
'类别编号：type_id';

comment on column traffic_type.parent_id is
'父类型编号：parent_id';

comment on column traffic_type.type_name is
'类别名称：type_name';

comment on column traffic_type.click is
'是否可点击：click';

comment on column traffic_type.search is
'是否可搜索：search';

comment on column traffic_type.description is
'类别描述：description';

comment on column traffic_type.order_id is
'排序：order_id';

comment on column traffic_type.memo is
'备注：memo';

comment on column traffic_type.colour is
'颜色：colour';

alter table area_info
    add constraint FK_AREA_INF_FK_AREA_I_AREA_TYP foreign key (type_id)
        references area_type (type_id)
        on delete restrict on update restrict;

alter table building_info
    add constraint FK_BUILDING_FK_BUILDI_BUILDING foreign key (type_id)
        references building_type (type_id)
        on delete restrict on update restrict;

alter table elevator_info
    add constraint FK_ELEVATOR_FK_ELEVAT_BUILDING foreign key (building_id)
        references building_info (building_id)
        on delete restrict on update restrict;

alter table equipment_info
    add constraint FK_EQUIPMEN_FK_EQUIPM_EQUIPMEN foreign key (type_id)
        references equipment_type (type_id)
        on delete restrict on update restrict;

alter table forewarning_info
    add constraint FK_FOREWARN_FK_FOREWA_EQUIPMEN foreign key (equipment_id)
        references equipment_info (equipment_id)
        on delete restrict on update restrict;

alter table organization_info
    add constraint FK_ORGANIZA_FK_ORGANI_AREA_INF foreign key (area_id)
        references area_info (area_id)
        on delete restrict on update restrict;

alter table organization_info
    add constraint FK_ORGANIZA_FK_ORGANI_BUILDING foreign key (building_id)
        references building_info (building_id)
        on delete restrict on update restrict;

alter table organization_info
    add constraint FK_ORGANIZA_FK_ORGANI_ORGANIZA foreign key (type_id)
        references organization_type (type_id)
        on delete restrict on update restrict;

alter table organization_info
    add constraint FK_ORGANIZA_FK_ORGANI_ROOM_INF foreign key (room_id)
        references room_info (room_id)
        on delete restrict on update restrict;

alter table plan_info
    add constraint FK_PLAN_INF_FK_PLAN_I_AREA_INF foreign key (area_id)
        references area_info (area_id)
        on delete restrict on update restrict;

alter table plan_info
    add constraint FK_PLAN_INF_FK_PLAN_I_PLAN_TYP foreign key (type_id)
        references plan_type (type_id)
        on delete restrict on update restrict;

alter table room_info
    add constraint FK_ROOM_INF_FK_ROOM_I_BUILDING foreign key (building_id)
        references building_info (building_id)
        on delete restrict on update restrict;

alter table room_info
    add constraint FK_ROOM_INF_FK_ROOM_I_HOUSE_TY foreign key (house_type_id)
        references house_type (type_id)
        on delete restrict on update restrict;

alter table room_info
    add constraint FK_ROOM_INF_FK_ROOM_I_ROOM_TYP foreign key (type_id)
        references room_type (type_id)
        on delete restrict on update restrict;

alter table station_info
    add constraint FK_STATION__FK_STATIO_TRAFFIC_ foreign key (traffic_id)
        references traffic_info (traffic_id)
        on delete restrict on update restrict;

alter table traffic_info
    add constraint FK_TRAFFIC__FK_TRAFFI_TRAFFIC_ foreign key (type_id)
        references traffic_type (type_id)
        on delete restrict on update restrict;

